@@ -1,5 +1,5 @@
 #/*##########################################################################
-# Copyright (C) 2004-2012 European Synchrotron Radiation Facility
+# Copyright (C) 2004-2013 European Synchrotron Radiation Facility
 #
 # This file is part of the PyMca X-ray Fluorescence Toolkit developed at
 # the ESRF by the Software group.
@@ -27,6 +27,7 @@
 __revision__ = "$Revision: 1.21 $"
 import sys
 from PyMca import PyMcaQt as qt
+
 if hasattr(qt, 'QString'):
     QString = qt.QString
 else:
@@ -34,6 +35,10 @@ else:
 
 QTVERSION = qt.qVersion()
 
+XRFMC_FLAG = False
+if QTVERSION > '4.0.0':
+    XRFMC_FLAG = True
+
 if QTVERSION < '4.0.0':
     import qttable
 
@@ -109,8 +114,16 @@ class Concentrations(qt.QWidget):
         if ddict['event'] == 'updated':
             self.concentrationsTool.configure(ddict)
             if self.__lastKw is not None:
+                addInfo = False
+                if 'addinfo' in self.__lastKw:
+                    if self.__lastKw['addinfo']:
+                        addInfo = True
                 try:
-                    ddict['concentrations'] = self.processFitResult(*self.__lastVar, **self.__lastKw)
+                    if addInfo:
+                        concentrations, info = self.processFitResult(*self.__lastVar, **self.__lastKw)
+                    else:
+                        concentrations = self.processFitResult(*self.__lastVar, **self.__lastKw)
+                    ddict['concentrations'] = concentrations
                 except:
                     self.__lastKw = None
                     raise
@@ -125,19 +138,33 @@ class Concentrations(qt.QWidget):
     def processFitResult(self, *var, **kw):
         self.__lastVar = var
         self.__lastKw = kw
+        addInfo = False
+        if 'addinfo' in kw:
+            if kw['addinfo']:
+                addInfo = True
         if DEBUG:
-            ddict = self.concentrationsTool.processFitResult(*var, **kw)
-            self.concentrationsTable.fillFromResult(ddict)
-            return ddict
+            if addInfo:
+                ddict, info = self.concentrationsTool.processFitResult(*var, **kw)
+                self.concentrationsTable.fillFromResult(ddict)
+                return ddict, info
+            else:
+                ddict = self.concentrationsTool.processFitResult(*var, **kw)
+                self.concentrationsTable.fillFromResult(ddict)
+                return ddict
         try:
             threadResult = self._submitThread(*var, **kw)
             if type(threadResult) == type((1,)):
                 if len(threadResult):
                     if threadResult[0] == "Exception":
                         raise Exception(threadResult[1], threadResult[2])
-            ddict = threadResult
-            self.concentrationsTable.fillFromResult(ddict)
-            return ddict
+            if addInfo:
+                ddict, info = threadResult
+                self.concentrationsTable.fillFromResult(ddict)
+                return ddict, info
+            else:
+                ddict = threadResult
+                self.concentrationsTable.fillFromResult(ddict)
+                return ddict
         except:
             self.__lastKw = None
             self.concentrationsTable.setRowCount(0)
@@ -243,6 +270,7 @@ class ConcentrationsWidget(qt.QWidget):
         ddict = {}
         ddict['usematrix'] = 0
         ddict['useattenuators'] = 1
+        ddict['usexrfmc'] = 0
         ddict['flux'] = 1.0E10
         ddict['time'] = 1.0
         ddict['area'] = 30.0
@@ -326,6 +354,12 @@ class ConcentrationsWidget(qt.QWidget):
         self.secondaryCheckBox.setText("Consider secondary excitation from deeper matrix layers (non intralayer nor above layers)")
         layout.addWidget(self.attenuatorsCheckBox)
         layout.addWidget( self.secondaryCheckBox)
+        #XRFMC secondary excitation
+        if XRFMC_FLAG:
+            self.xrfmcCheckBox = qt.QCheckBox(self)
+            self.xrfmcCheckBox.setText("use Monte Carlo code to correct higher order excitations")
+            layout.addWidget( self.xrfmcCheckBox)
+
         #mM checkbox
         self.mMolarCheckBox = qt.QCheckBox(self)
         self.mMolarCheckBox.setText("Elemental mM concentrations (assuming 1 l of solution is 1000 * matrix_density grams)")
@@ -345,8 +379,15 @@ class ConcentrationsWidget(qt.QWidget):
                          self.checkBoxSlot)
         self.connect(self.attenuatorsCheckBox, qt.SIGNAL("clicked()"),
                      self.checkBoxSlot)
-        self.connect(self.secondaryCheckBox, qt.SIGNAL("clicked()"),
-                     self.checkBoxSlot)
+        if XRFMC_FLAG:
+            self.connect(self.secondaryCheckBox, qt.SIGNAL("clicked()"),
+                         self._secondaryCheckBoxSlot)
+            self.connect(self.xrfmcCheckBox, qt.SIGNAL("clicked()"),
+                         self._xrfmcCheckBoxSlot)
+        else:
+            self.connect(self.secondaryCheckBox, qt.SIGNAL("clicked()"),
+                         self.checkBoxSlot)
+            
         self.connect(self.mMolarCheckBox, qt.SIGNAL("clicked()"),
                      self.checkBoxSlot)
 
@@ -376,6 +417,16 @@ class ConcentrationsWidget(qt.QWidget):
             self.matrixCheckBox.setChecked(True)
         self.checkBoxSlot()
 
+    def _secondaryCheckBoxSlot(self):
+        if self.secondaryCheckBox.isChecked():
+            self.xrfmcCheckBox.setChecked(False)
+        self.checkBoxSlot()
+
+    def _xrfmcCheckBoxSlot(self):
+        if self.xrfmcCheckBox.isChecked():
+            self.secondaryCheckBox.setChecked(False)
+        self.checkBoxSlot()
+
     def checkBoxSlot(self):
         if self.matrixCheckBox.isChecked():
             self.fundamentalWidget.setInputDisabled(True)
@@ -387,6 +438,8 @@ class ConcentrationsWidget(qt.QWidget):
             self.referenceLine.setEnabled(False)
             if QTVERSION > '4.0.0':
                 self.fluxCheckBox.setChecked(True)
+                self.connect(self.secondaryCheckBox, qt.SIGNAL("clicked()"),
+                     self.checkBoxSlot)
         self._mySignal()
 
     def _referenceLineSlot(self, ddict):
@@ -400,6 +453,7 @@ class ConcentrationsWidget(qt.QWidget):
             elif len(current) == 1:
                 current = current.upper()[0]
             else:
+                self.referenceLine.setText('Auto')
                 msg = qt.QMessageBox(self.referenceLine)
                 msg.setIcon(qt.QMessageBox.Critical)
                 msg.setText("Invalid Element %s" % current)
@@ -410,8 +464,10 @@ class ConcentrationsWidget(qt.QWidget):
                 self.referenceLine.setFocus()
                 return
             if (current == '') or (current.upper() == 'AUTO'):
+                self.referenceLine.setText('Auto')
                 self._mySignal()
             elif not Elements.isValidFormula(current):
+                self.referenceLine.setText('Auto')
                 msg = qt.QMessageBox(self.referenceLine)
                 msg.setIcon(qt.QMessageBox.Critical)
                 msg.setText("Invalid Element %s" % current)
@@ -419,8 +475,6 @@ class ConcentrationsWidget(qt.QWidget):
                     msg.exec_loop()
                 else:
                     msg.exec_()
-
-                self.referenceLine.setText('Auto')
                 self.referenceLine.setFocus()
             else:
                 self.referenceLine.setText(current)
@@ -449,6 +503,10 @@ class ConcentrationsWidget(qt.QWidget):
             ddict['usemultilayersecondary'] = 1
         else:
             ddict['usemultilayersecondary'] = 0
+        ddict['usexrfmc'] = 0
+        if XRFMC_FLAG:
+            if self.xrfmcCheckBox.isChecked():
+                ddict['usexrfmc'] = 1
         if self.mMolarCheckBox.isChecked():
             ddict['mmolarflag'] = 1
         else:
@@ -472,6 +530,13 @@ class ConcentrationsWidget(qt.QWidget):
         else:
             self.secondaryCheckBox.setChecked(False)
 
+        if XRFMC_FLAG:
+            if 'usexrfmc' in ddict:
+                if ddict['usexrfmc']:
+                    self.xrfmcCheckBox.setChecked(True)
+                else:
+                    self.xrfmcCheckBox.setChecked(False)
+
         if 'mmolarflag' in ddict:
             if ddict['mmolarflag']:
                 self.mMolarCheckBox.setChecked(True)
@@ -546,7 +611,7 @@ class FundamentalWidget(qt.QWidget):
         c0l0.setText("Flux (photons/s)")
 
         c0l1 = qt.QLabel(c0)
-        c0l1.setText("Active Area (mm2)")
+        c0l1.setText("Active Area (cm2)")
 
         c0.layout.addWidget(c0l0)
         c0.layout.addWidget(c0l1)
@@ -576,7 +641,7 @@ class FundamentalWidget(qt.QWidget):
         c2l0.setText("x time(seconds)")
 
         c2l1 = qt.QLabel(c2)
-        c2l1.setText("distance (mm)")
+        c2l1.setText("distance (cm)")
 
         c2.layout.addWidget(c2l0)
         c2.layout.addWidget(c2l1)
