@@ -1,5 +1,5 @@
 #/*##########################################################################
-# Copyright (C) 2004-2012 European Synchrotron Radiation Facility
+# Copyright (C) 2004-2014 European Synchrotron Radiation Facility
 #
 # This file is part of the PyMca X-ray Fluorescence Toolkit developed at
 # the ESRF by the Software group.
@@ -25,7 +25,7 @@ __author__ = "V.A. Sole - ESRF Data Analysis"
 
 ################################################################################  
 #import fast_EdfFile as EdfFile
-from PyMca import EdfFile
+from PyMca.PyMcaIO import EdfFile
 ################################################################################
 
 SOURCE_TYPE = "EdfFile"
