@@ -1,5 +1,5 @@
 #/*##########################################################################
-# Copyright (C) 2004-2012 European Synchrotron Radiation Facility
+# Copyright (C) 2004-2014 European Synchrotron Radiation Facility
 #
 # This file is part of the PyMca X-ray Fluorescence Toolkit developed at
 # the ESRF by the Software group.
@@ -38,7 +38,7 @@ else:
 from PyMca.PyMca_Icons import IconDict
 from PyMca import MaskImageWidget
 try:
-    from PyMca import EdfFile
+    from PyMca.PyMcaIO import EdfFile
     EDF = True
 except ImportError:
     EDF = False
@@ -116,10 +116,10 @@ class ExternalImagesWindow(MaskImageWidget.MaskImageWidget):
                                      self._flipLeftRight)
             self._flipMenu.addAction(QString("Flip Image Up-Down"),
                                      self._flipUpDown)
-        #else:
-        #    self.connect(self.graphWidget.hFlipToolButton,
-        #         qt.SIGNAL("clicked()"),
-        #         self.__hFlipIconSignal)
+        else:
+            self.connect(self.graphWidget.hFlipToolButton,
+                 qt.SIGNAL("clicked()"),
+                 self.__hFlipIconSignal)
 
 
     def sizeHint(self):
