@@ -1,5 +1,5 @@
 #/*##########################################################################
-# Copyright (C) 2004-2013 European Synchrotron Radiation Facility
+# Copyright (C) 2004-2014 European Synchrotron Radiation Facility
 #
 # This file is part of the PyMca X-ray Fluorescence Toolkit developed at
 # the ESRF by the Software group.
@@ -91,7 +91,11 @@ class HDF5Stack1D(DataObject.DataObject):
 
         # built the selection in terms of HDF terms
         # for the time being, only the first item in x selection used
+        
         xSelection = selection['x']
+        if xSelection is not None:
+            if type(xSelection) != type([]):
+                xSelection = [xSelection]
         if type(xSelection) == type([]):
             if len(xSelection):
                 xSelection = xSelection[0]
@@ -106,6 +110,9 @@ class HDF5Stack1D(DataObject.DataObject):
 
         # monitor selection
         mSelection = selection['m']
+        if mSelection not in [None, []]:
+            if type(mSelection) != type([]):
+                mSelection = [mSelection]            
         if type(mSelection) == type([]):
             if len(mSelection):
                 mSelection = mSelection[0]
@@ -122,6 +129,7 @@ class HDF5Stack1D(DataObject.DataObject):
                 if len(scanlist) == 1:
                     if scanlist[0] == ySelection:
                         scanlist = None
+                        USE_JUST_KEYS = True
         elif len(entryNames) == 1:
             # deal with the SOLEIL case of one entry but with different name
             # in different files
