@@ -1,6 +1,22 @@
-"""
-"""
-from __future__ import with_statement
+#/*##########################################################################
+# Copyright (C) 2004-2013 European Synchrotron Radiation Facility
+#
+# This file is part of the PyMca X-ray Fluorescence Toolkit developed at
+# the ESRF by the Software group.
+#
+# This toolkit is free software; you can redistribute it and/or modify it
+# under the terms of the GNU Lesser General Public License as published by the Free
+# Software Foundation; either version 2 of the License, or (at your option)
+# any later version.
+#
+# PyMca is distributed in the hope that it will be useful, but WITHOUT ANY
+# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+# FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
+# details.
+#
+#############################################################################*/
+__author__ = "Darren Dale (CHESS) & V.A. Sole (ESRF)"
+__license__ = "GPL2+ if used with PyQt - LGPL2+ if adapted to PySide"
 import sys
 import os
 import posixpath
@@ -35,18 +51,18 @@ def h5py_sorting(object_list):
     if n < 2:
         return object_list
 
+    # we have received items, not values
+    posixNames = [item[1].name for item in object_list]
+    
     # This implementation only sorts entries
-    if posixpath.dirname(object_list[0].name) != "/":
+    if posixpath.dirname(posixNames[0]) != "/":
         return object_list
 
-    names = list(object_list[0].keys())
-
     sorting_key = None
     for key in sorting_list:
-        if key in names:
+        if key in object_list[0][1]:
             sorting_key = key
             break
-        
     if sorting_key is None:
         if 'name' in sorting_list:
             sorting_key = 'name'
@@ -55,13 +71,13 @@ def h5py_sorting(object_list):
 
     try:
         if sorting_key != 'name':
-            sorting_list = [(o[sorting_key].value, o)
+            sorting_list = [(o[1][sorting_key].value, o)
                            for o in object_list]
             sorted_list = sorted(sorting_list, key=itemgetter(0))
             return [x[1] for x in sorted_list]
 
         if sorting_key == 'name':
-            sorting_list = [(_get_number_list(o.name),o)
+            sorting_list = [(_get_number_list(o[1].name),o)
                            for o in object_list]
             sorting_list.sort()
             return [x[1] for x in sorting_list]
@@ -148,17 +164,37 @@ class H5NodeProxy(object):
             # obtaining the lock here is necessary, otherwise application can
             # freeze if navigating tree while data is processing
             if 1: #with self.file.plock:
-                tmpList = list(self.getNode(self.name).values())
+                items = self.getNode(self.name).items()
+                # previous line seems to retrieve an iterator under Python 3.3
+                if (sys.version > '3.2') and\
+                   (h5py.version.version > '2.1.1'):
+                    items = list(items)
+                if posixpath.dirname(self.name) == "/":
+                    # top level item
+                    doit = True
+                else:
+                    doit = False
                 try:
-                    finalList = h5py_sorting(tmpList)
+                    # better handling of external links
+                    finalList = h5py_sorting(items)
+                    for i in range(len(finalList)):
+                        finalList[i][1]._posixPath = posixpath.join(self.name,
+                                                               finalList[i][0])
+                    self._children = [H5NodeProxy(self.file, i[1], self)
+                                      for i in finalList]
                 except:
-                    #one cannot afford any error
+                    #one cannot afford any error, so I revert to the old
+                    # method where values where used instead of items
                     if DEBUG:
                         raise
                     else:
+                        tmpList = list(self.getNode(self.name).values())                
                         finalList = tmpList
-                self._children = [H5NodeProxy(self.file, i, self)
-                                  for i in finalList]
+                    for i in range(len(finalList)):
+                        finalList[i]._posixPath = posixpath.join(self.name,
+                                                               items[i][0])
+                    self._children = [H5NodeProxy(self.file, i, self)
+                                      for i in finalList]
         return self._children
 
     @property
@@ -207,11 +243,14 @@ class H5NodeProxy(object):
         return self._parent
 
 
-    def __init__(self, ffile, node, parent=None):
+    def __init__(self, ffile, node, parent=None, path=None):
         if 1:#with ffile.plock:
             self._file = ffile
-            self._parent = parent
-            self._name = node.name
+            self._parent = parent    
+            if hasattr(node, '_posixPath'):
+                self._name = node._posixPath
+            else:
+                self._name = node.name
             """
             if hasattr(node, "_sourceName"):
                 self._name = node._sourceName
@@ -273,7 +312,7 @@ class H5FileProxy(H5NodeProxy):
         self._filename = self.file.name
 
     def close(self):
-        with self.file.plock:
+        if 1: # with self.file.plock:
             return self.file.close()
 
     def __getitem__(self, path):
@@ -618,7 +657,6 @@ if __name__ == "__main__":
         sys.exit(0)
     fileModel = FileModel()
     fileView = HDF5Widget(fileModel)
-    #fileModel.openFile('/home/darren/temp/PSI.hdf')
     phynxFile = fileModel.openFile(sys.argv[1])
     def mySlot(ddict):
         print(ddict)
