@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 #/*##########################################################################
-# Copyright (C) 2004-2012 European Synchrotron Radiation Facility
+# Copyright (C) 2004-2014 European Synchrotron Radiation Facility
 #
 # This file is part of the PyMca X-ray Fluorescence Toolkit developed at
 # the ESRF by the Software group.
@@ -37,7 +37,7 @@ if QTVERSION >= '4.0.0':
     qt.Qt.WDestructiveClose = "TO BE DONE"
 from PyMca.PyMca_Icons import IconDict
 from PyMca import McaCustomEvent
-from PyMca import EdfFile
+from PyMca.PyMcaIO import EdfFile
 from PyMca import SpecFileLayer
 from PyMca import PyMcaDirs
 
