@@ -1,5 +1,5 @@
 #/*##########################################################################
-# Copyright (C) 2004-2013 European Synchrotron Radiation Facility
+# Copyright (C) 2004-2014 European Synchrotron Radiation Facility
 #
 # This file is part of the PyMca X-ray Fluorescence Toolkit developed at
 # the ESRF by the Software group.
@@ -31,10 +31,10 @@ import numpy
 from PyMca import ClassMcaTheory
 from PyMca import SpecFileLayer
 from PyMca import EdfFileLayer
-from PyMca import EdfFile
-from PyMca import LuciaMap
-from PyMca import AifiraMap
-from PyMca import EDFStack
+from PyMca.PyMcaIO import EdfFile
+from PyMca.PyMcaIO import LuciaMap
+from PyMca.PyMcaIO import AifiraMap
+from PyMca.PyMcaIO import EDFStack
 try:
     import h5py
     from PyMca import HDF5Stack1D
@@ -276,6 +276,14 @@ class McaAdvancedFitBatch(object):
         stack = self.file
         info = stack.info
         data = stack.data
+        xStack = None
+        if hasattr(stack, "x"):
+            if stack.x not in [None, []]:
+                if type(stack.x) == type([]):
+                    xStack = stack.x[0]
+                else:
+                    print("THIS SHOULD NOT BE USED")
+                    xStack = stack.x
         nimages = stack.info['Dim_1']
         self.__nrows = nimages
         numberofmca = stack.info['Dim_2']
@@ -303,14 +311,17 @@ class McaAdvancedFitBatch(object):
                 if self.pleaseBreak: break
                 self.__col = mca
                 mcadata = cache_data[mca, :]
-                if 'MCA start ch' in info:
-                    xmin = float(info['MCA start ch'])
+                y0  = numpy.array(mcadata)
+                if xStack is None:
+                    if 'MCA start ch' in info:
+                        xmin = float(info['MCA start ch'])
+                    else:
+                        xmin = 0.0
+                    x = numpy.arange(len(y0))*1.0 + xmin
                 else:
-                    xmin = 0.0
+                    x = xStack
                 #key = "%s.%s.%02d.%02d" % (scan,order,row,col)
                 key = "%s.%04d" % (keylist[i], mca)
-                y0  = numpy.array(mcadata)
-                x = numpy.arange(len(y0))*1.0 + xmin
                 #I only process the first file of the stack?
                 filename = os.path.basename(info['SourceName'][0])
                 infoDict = {}
@@ -334,17 +345,14 @@ class McaAdvancedFitBatch(object):
                 if info['SourceType'] == "EdfFile":
                     nrows = int(info['Dim_1'])
                     ncols = int(info['Dim_2'])
-                    numberofmca  = min(nrows,ncols)
+                    numberofmca  = ncols
                     self.__ncols = len(range(0+self.mcaOffset,numberofmca,self.mcaStep))
                     self.__col  = -1
                     for mca_index in range(self.__ncols):
                         mca = 0 + self.mcaOffset + mca_index * self.mcaStep
                         if self.pleaseBreak: break
                         self.__col += 1
-                        if int(nrows) > int(ncols):
-                            mcadata = data[mca,:]
-                        else:
-                            mcadata = data[:,mca]
+                        mcadata = data[mca,:]
                         if 'MCA start ch' in info:
                             xmin = float(info['MCA start ch'])
                         else:
