@@ -834,8 +834,8 @@ def mdpICA(stack, ncomponents=10, binning=None, dtype='float64', svd='True',
 
 
 def main():
-    from PyMca import EDFStack
-    from PyMca import EdfFile
+    from PyMca.PyMcaIO import EDFStack
+    from PyMca.PyMcaIO import EdfFile
     import sys
     inputfile = "D:\DATA\COTTE\ch09\ch09__mca_0005_0000_0000.edf"
     if len(sys.argv) > 1:
