@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 #/*##########################################################################
-# Copyright (C) 2004-2012 European Synchrotron Radiation Facility
+# Copyright (C) 2004-2014 European Synchrotron Radiation Facility
 #
 # This file is part of the PyMca X-ray Fluorescence Toolkit developed at
 # the ESRF by the Software group.
@@ -27,7 +27,7 @@
 #############################################################################*/
 import os
 import numpy
-from PyMca import EdfFile
+from PyMca.PyMcaIO import EdfFile
 
 DEBUG = 0
 
