@@ -25,7 +25,7 @@
 # Please contact the ESRF industrial unit (industry@esrf.fr) if this license
 # is a problem for you.
 #############################################################################*/
-__author__ = "V.A. Sole - ESRF BLISS Group"
+__author__ = "V.A. Sole - ESRF Software Group"
 import os
 import numpy
 from matplotlib import cm
@@ -34,6 +34,7 @@ from matplotlib.font_manager import FontProperties
 from matplotlib.backends.backend_agg import FigureCanvasAgg as FigureCanvas
 from matplotlib.figure import Figure
 from matplotlib.colors import LinearSegmentedColormap, LogNorm, Normalize
+from matplotlib.ticker import MaxNLocator, AutoLocator
 
 DEBUG = 0
 
@@ -254,22 +255,25 @@ class PyMcaMatplotlibSave(FigureCanvas):
 
 class PyMcaMatplotlibSaveImage:
     def __init__(self, imageData=None, fileName=None,
-		     dpi=300,
+                     dpi=300,
                      size=(5, 5),
                      xaxis='off',
                      yaxis='off',
                      xlabel='',
                      ylabel='',
+                     nxlabels=0,
+                     nylabels=0,
                      colorbar=None,
                      title='',
                      interpolation='nearest',
-		     colormap=None,
+                     colormap=None,
                      linlogcolormap='linear',                 
                      origin='lower',
-		     contour='off',
-		     contourlabels='on',
-		     contourlabelformat='%.3f',
+                     contour='off',
+                     contourlabels='on',
+                     contourlabelformat='%.3f',
                      contourlevels=10,
+                     contourlinewidth=10,
                      xorigin=0.0,
                      yorigin=0.0,
                      xpixelsize=1.0,
@@ -288,6 +292,8 @@ class PyMcaMatplotlibSaveImage:
                     'title':title,
                     'xlabel':xlabel,
                     'ylabel':ylabel,
+                    'nxlabels':nxlabels,
+                    'nylabels':nylabels,
                     'colorbar':colorbar,
                     'colormap':colormap,
                     'linlogcolormap':linlogcolormap,                     
@@ -296,7 +302,8 @@ class PyMcaMatplotlibSaveImage:
                     'contour':contour,
                     'contourlabels':contourlabels,
                     'contourlabelformat':contourlabelformat,
-                    'contourlevels':10,
+                    'contourlevels':contourlevels,
+                    'contourlinewidth':contourlinewidth,
                     'xpixelsize':xpixelsize,
                     'ypixelsize':ypixelsize,
                     'xorigin':xorigin,
@@ -385,10 +392,19 @@ class PyMcaMatplotlibSaveImage:
             self.axes.xaxis.set_visible(False)
         else:
             self.axes.xaxis.set_visible(True)
+            nLabels = self.config['nxlabels']
+            if nLabels not in ['Auto', 'auto', '0', 0]:
+                self.axes.xaxis.set_major_locator(MaxNLocator(nLabels))
+            else:
+                self.axes.xaxis.set_major_locator(AutoLocator())
         if self.config['yaxis'] == 'off':
             self.axes.yaxis.set_visible(False)
         else:
             self.axes.yaxis.set_visible(True)
+            if nLabels not in ['Auto', 'auto', '0', 0]:
+                self.axes.yaxis.set_major_locator(MaxNLocator(nLabels))
+            else:
+                self.axes.yaxis.set_major_locator(AutoLocator())
 
         if self.pixmapImage is not None:
             self._savePixmapFigure(filename)
@@ -427,6 +443,32 @@ class PyMcaMatplotlibSaveImage:
             cmap = self.__blueCmap
         elif self.config['colormap']=='temperature':
             cmap = self.__temperatureCmap
+        elif self.config['colormap'] == 'paired':
+            cmap = cm.Paired
+        elif self.config['colormap'] == 'paired_r':
+            cmap = cm.Paired_r
+        elif self.config['colormap'] == 'pubu':
+            cmap = cm.PuBu
+        elif self.config['colormap'] == 'pubu_r':
+            cmap = cm.PuBu_r
+        elif self.config['colormap'] == 'rdbu':
+            cmap = cm.RdBu
+        elif self.config['colormap'] == 'rdbu_r':
+            cmap = cm.RdBu_r
+        elif self.config['colormap'] == 'gist_earth':
+            cmap = cm.gist_earth
+        elif self.config['colormap'] == 'gist_earth_r':
+            cmap = cm.gist_earth_r
+        elif self.config['colormap'] == 'blues':
+            cmap = cm.Blues
+        elif self.config['colormap'] == 'blues_r':
+            cmap = cm.Blues_r
+        elif self.config['colormap'] == 'ylgnbu':
+            cmap = cm.YlGnBu
+        elif self.config['colormap'] == 'ylgnbu_r':
+            cmap = cm.YlGnBu_r
+        else:
+            print("Unsupported colormap %s" % self.config['colormap'])
 
         if self.config['extent'] is None:
             h, w = self.imageData.shape
@@ -486,6 +528,7 @@ class PyMcaMatplotlibSaveImage:
             dataMin = imageData.min()
             dataMax = imageData.max()
             ncontours = int(self.config['contourlevels'])
+            contourlinewidth = int(self.config['contourlinewidth'])/10.
             levels = (numpy.arange(ncontours)) *\
                      (dataMax - dataMin)/float(ncontours)
             if self.config['contour'] == 'filled':
@@ -497,7 +540,7 @@ class PyMcaMatplotlibSaveImage:
                 self._contour = self.axes.contour(imageData, levels,
                      origin=origin,
                      cmap=ccmap,
-                     linewidths=2,
+                     linewidths=contourlinewidth,
                      extent=extent)
             if self.config['contourlabels'] != 'off':                
                 self.axes.clabel(self._contour, fontsize=9,
