@@ -1,5 +1,5 @@
 #/*##########################################################################
-# Copyright (C) 2004-2013 European Synchrotron Radiation Facility
+# Copyright (C) 2013-2014 European Synchrotron Radiation Facility
 #
 # This file is part of the PyMca X-ray Fluorescence Toolkit developed at
 # the ESRF by the Software group.
@@ -64,9 +64,9 @@ from PyMca import FFTAlignmentWindow
 from PyMca import ImageRegistration
 from PyMca import SpecfitFuns
 from PyMca import CalculationThread
-from PyMca import ArraySave
+from PyMca.PyMcaIO import ArraySave
 from PyMca import PyMcaFileDialogs
-from PyMca import specfilewrapper
+from PyMca.PyMcaIO import specfilewrapper
 from PyMca import HDF5Widget
 
 try:
@@ -170,8 +170,6 @@ class ImageAlignmentStackPlugin(StackPluginBase.StackPluginBase):
                     raise Exception(result[1], result[2], result[3])
                 else:
                     shifts = result
-                if filename is not None:
-                    self.__hdf5 = self.initializeHDF5File(filename)
                 result = self.__shiftStack(stack,
                                            shifts,
                                            crop=crop,
@@ -323,7 +321,9 @@ class ImageAlignmentStackPlugin(StackPluginBase.StackPluginBase):
             if filename is None:
                 self.setStack(stack)
         
-    def calculateShiftsSIFT(self, stack, reference, mask=None, device=None, crop=None, filename=None):
+    def calculateShiftsSIFT(self, stack, reference, mask=None, device=None, crop=None,
+                            sigma=None,
+                            filename=None):
         mask = self.getStackSelectionMask()
         if mask is not None:
             if mask.sum() == 0:
@@ -333,19 +333,24 @@ class ImageAlignmentStackPlugin(StackPluginBase.StackPluginBase):
                 max_workgroup_size = 1
                 siftInstance = sift.LinearAlign(reference.astype(numpy.float32),
                                                 max_workgroup_size=max_workgroup_size,
-                                                devicetype="cpu")
+                                                devicetype="cpu",
+                                                init_sigma=sigma)
             else:
                 siftInstance = sift.LinearAlign(reference.astype(numpy.float32),
-                                                devicetype="cpu")
+                                                devicetype="cpu",
+                                                init_sigma=sigma)
         else:
             deviceType = sift.opencl.ocl.platforms[device[0]].devices[device[1]].type
             if deviceType.lower() == "cpu" and sys.platform == 'darwin':
                 max_workgroup_size = 1
                 siftInstance = sift.LinearAlign(reference.astype(numpy.float32),
                                                 max_workgroup_size=max_workgroup_size,
-                                                device=device)
+                                                device=device,
+                                                init_sigma=sigma)
             else:               
-                siftInstance = sift.LinearAlign(reference.astype(numpy.float32), device=device)
+                siftInstance = sift.LinearAlign(reference.astype(numpy.float32),
+                                                device=device,
+                                                init_sigma=sigma)
         data = stack.data
         mcaIndex = stack.info['McaIndex']
         if not (mcaIndex in [0, 2, -1]):
@@ -549,6 +554,7 @@ class ImageAlignmentStackPlugin(StackPluginBase.StackPluginBase):
             if not ret:
                 return
             shifts = hdf5File[self.__shitfsDataset].value
+            hdf5File.close()
         else:
             sf = specfilewrapper.Specfile(filename)
             nScans = len(sf)
@@ -660,9 +666,10 @@ class ImageAlignmentStackPlugin(StackPluginBase.StackPluginBase):
             shape = data[mcaIndex].shape
         else:
             shape = data.shape[0], data.shape[1]
-        d0_start, d0_end, d1_start, d1_end = ImageRegistration.get_crop_indices(shape,
-                                                                                shifts[:, 0],
-                                                                                shifts[:, 1])
+        d0_start, d0_end, d1_start, d1_end = \
+                  ImageRegistration.get_crop_indices(shape,
+                                                     shifts[:, 0],
+                                                     shifts[:, 1])
         window = numpy.zeros(shape, numpy.float32)
         window[d0_start:d0_end, d1_start:d1_end] = 1.0
         self._progress = 0.0
@@ -684,6 +691,7 @@ class ImageAlignmentStackPlugin(StackPluginBase.StackPluginBase):
             #tmpImage = ImageRegistration.shiftFFT(data[i], shifts[i])
             if mcaIndex == 0:
                 tmpImage = ImageRegistration.shiftBilinear(data[i], shifts[i])
+                #tmpImage = ImageRegistration.shiftImage(data[i], -shifts[i], method="fft")
                 if filename is None:
                     stack.data[i] = tmpImage * window
                 else:
@@ -700,6 +708,8 @@ class ImageAlignmentStackPlugin(StackPluginBase.StackPluginBase):
 
     def initializeHDF5File(self, fname):
         #for the time being overwriting
+        if os.path.exists(fname):
+            os.remove(fname)            
         hdf = h5py.File(fname, 'w')
         entryName = "entry_000"
         nxEntry = hdf.require_group(entryName)
@@ -717,7 +727,9 @@ class ImageAlignmentStackPlugin(StackPluginBase.StackPluginBase):
         #add final date
         toplevelEntry = hdf["entry_000"]
         toplevelEntry['end_time'] = numpy.string_(ArraySave.getDate().encode('utf-8'))
-    
+        hdf.flush()
+        hdf.close()
+        
     def getHDF5BufferIntoGroup(self, h5Group, shape,
                                name="data", dtype=numpy.float32,
                                attributes=None,
