@@ -1,27 +1,27 @@
 #/*##########################################################################
-# Copyright (C) 2004-2009 European Synchrotron Radiation Facility
+# Copyright (C) 2004-2012 European Synchrotron Radiation Facility
 #
-# This file is part of the PyMCA X-ray Fluorescence Toolkit developed at
-# the ESRF by the Beamline Instrumentation Software Support (BLISS) group.
+# This file is part of the PyMca X-ray Fluorescence Toolkit developed at
+# the ESRF by the Software group.
 #
-# This toolkit is free software; you can redistribute it and/or modify it 
+# This toolkit is free software; you can redistribute it and/or modify it
 # under the terms of the GNU General Public License as published by the Free
-# Software Foundation; either version 2 of the License, or (at your option) 
+# Software Foundation; either version 2 of the License, or (at your option)
 # any later version.
 #
-# PyMCA is distributed in the hope that it will be useful, but WITHOUT ANY
+# PyMca is distributed in the hope that it will be useful, but WITHOUT ANY
 # WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 # FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
 # details.
 #
 # You should have received a copy of the GNU General Public License along with
-# PyMCA; if not, write to the Free Software Foundation, Inc., 59 Temple Place,
-# Suite 330, Boston, MA 02111-1307, USA.
+# PyMca; if not, write to the Free Software Foundation, Inc.,
+# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
-# PyMCA follows the dual licensing model of Trolltech's Qt and Riverbank's PyQt
-# and cannot be used as a free plugin for a non-free program. 
+# PyMca follows the dual licensing model of Riverbank's PyQt and cannot be
+# used as a free plugin for a non-free program.
 #
-# Please contact the ESRF industrial unit (industry@esrf.fr) if this license 
+# Please contact the ESRF industrial unit (industry@esrf.fr) if this license
 # is a problem for you.
 #############################################################################*/
 # --- scan window icons ---
@@ -145,6 +145,8 @@ subtract =[
 "                "
 ]
 
+substract = subtract
+
 smooth = [
 "16 16 3 1",
 "O c none",
@@ -283,6 +285,72 @@ average16=[
 "                "
 ]
 
+horizontal=[
+"16 16 2 1",
+". c blue",
+"  c None",
+"                ",
+"                ",
+"                ",
+"                ",
+"                ",
+"                ",
+"                ",
+" .............. ",
+" .............. ",
+"                ",
+"                ",
+"                ",
+"                ",
+"                ",
+"                ",
+"                "
+]
+
+vertical=[
+"16 16 2 1",
+". c blue",
+"  c None",
+"                ",
+"       ..       ",
+"       ..       ",
+"       ..       ",
+"       ..       ",
+"       ..       ",
+"       ..       ",
+"       ..       ",
+"       ..       ",
+"       ..       ",
+"       ..       ",
+"       ..       ",
+"       ..       ",
+"       ..       ",
+"       ..       ",
+"                "
+]
+
+diagonal =[
+"16 16 2 1",
+". c blue",
+"  c None",
+"                ",
+" ..             ",
+"  ..            ",
+"   ..           ",
+"    ..          ",
+"     ..         ",
+"      ..        ",
+"       ..       ",
+"        ..      ",
+"         ..     ",
+"          ..    ",
+"           ..   ",
+"            ..  ",
+"             .. ",
+"              . ",
+"                "
+]
+
 # -------------------------
 sliderson=[
 "16 16 2 1",
@@ -3366,37 +3434,41 @@ IconDict= {
     "average16":average16,
     "smooth":smooth,
     "subtract":subtract,
+    "substract":substract,
     "togglepoints":togglepoints,
     "remove":remove,
     "additionalselect":additionalselect,
     "crop":crop,
-    "plugin":plugin
+    "plugin":plugin,
+    "horizontal":horizontal,
+    "vertical":vertical,
+    "diagonal":diagonal
 }
 
 def showIcons():
-	import sys
-	import PyMcaQt as qt
-	a= qt.QApplication(sys.argv)
-	a.connect(a, qt.SIGNAL("lastWindowClosed()"), a.quit)
-	w= qt.QWidget()
-	g= qt.QGridLayout(w)
+    import sys
+    from PyMca import PyMcaQt as qt
+    a= qt.QApplication(sys.argv)
+    a.connect(a, qt.SIGNAL("lastWindowClosed()"), a.quit)
+    w= qt.QWidget()
+    g= qt.QGridLayout(w)
 
-	idx= 0
-	for name,icon in IconDict.items():
-                #print "name",name
-		lab= qt.QLabel(w)
-		lab.setText(str(name))
-		g.addWidget(lab, idx, 0)
-		lab= qt.QLabel(w)
-		lab.setPixmap(qt.QPixmap(icon))
-		g.addWidget(lab, idx, 1)
-		idx+= 1
+    idx= 0
+    for name,icon in IconDict.items():
+        #print "name",name
+        lab= qt.QLabel(w)
+        lab.setText(str(name))
+        g.addWidget(lab, idx, 0)
+        lab= qt.QLabel(w)
+        lab.setPixmap(qt.QPixmap(icon))
+        g.addWidget(lab, idx, 1)
+        idx+= 1
 
-	w.show()
-	if qt.qVersion () < '4.0.0':
-        	a.exec_loop()
-        else:
-                a.exec_()
+    w.show()
+    if qt.qVersion () < '4.0.0':
+        a.exec_loop()
+    else:
+        a.exec_()
 
 if __name__=='__main__':
-	showIcons()
+    showIcons()
