@@ -1,5 +1,5 @@
 #/*##########################################################################
-# Copyright (C) 2004-2012 European Synchrotron Radiation Facility
+# Copyright (C) 2004-2014 European Synchrotron Radiation Facility
 #
 # This file is part of the PyMca X-ray Fluorescence Toolkit developed at
 # the ESRF by the Software group.
@@ -51,7 +51,7 @@ else:
 from PyMca.PyMca_Icons import IconDict
 from PyMca import ColormapDialog
 from PyMca import PyMcaPrintPreview
-from PyMca import ArraySave
+from PyMca.PyMcaIO import ArraySave
 from PyMca import PyMcaDirs
 from PyMca import SpecFileDataInfo
 
