@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 #/*##########################################################################
-# Copyright (C) 2004-2013 European Synchrotron Radiation Facility
+# Copyright (C) 2004-2014 European Synchrotron Radiation Facility
 #
 # This file is part of the PyMca X-ray Fluorescence Toolkit developed at
 # the ESRF by the Software group.
@@ -47,7 +47,7 @@ from PyMca.RGBCorrelatorWidget import ImageShapeDialog
 from PyMca.PyMca_Icons import IconDict
 from PyMca import StackSelector
 from PyMca import PyMcaDirs
-from PyMca import ArraySave
+from PyMca.PyMcaIO import ArraySave
 HDF5 = ArraySave.HDF5
 
 DEBUG = 0
@@ -545,6 +545,8 @@ class QStackWidget(StackBase.StackBase,
         actionList.append(text)
         menu.addSeparator()
         callableKeys = ["Dummy0", "Dummy1", "Dummy2"]
+        additionalItems = []
+        SORTED = True
         for m in self.pluginList:
             if m == "PyMcaPlugins.StackPluginBase":
                 continue
@@ -561,6 +563,14 @@ class QStackWidget(StackBase.StackBase,
             methods = self.pluginInstanceDict[m].getMethods()
             if not len(methods):
                 continue
+            if SORTED:
+                additionalItems.append((text, m))
+            else:
+                menu.addAction(text)
+                actionList.append(text)
+                callableKeys.append(m)
+        additionalItems.sort()
+        for text, m in additionalItems:
             menu.addAction(text)
             actionList.append(text)
             callableKeys.append(m)
