@@ -31,39 +31,40 @@ from PyMca import SpecfitGUI
 from PyMca import Specfit
 QTVERSION = qt.qVersion()
 
+
 class ScanFit(qt.QWidget):
-    def __init__(self, parent=None, name="ScanFit", specfit=None,fl=0): 
+    def __init__(self, parent=None, name="ScanFit", specfit=None, fl=0):
                 #fl=qt.Qt.WDestructiveClose):
         qt.QWidget.__init__(self, parent)
         if QTVERSION < '4.0.0':
             self.setCaption(name)
         else:
             self.setWindowTitle(name)
-            
+
         if specfit is None:
             self.specfit = Specfit.Specfit()
         else:
             self.specfit = specfit
-        self.info = None            
+        self.info = None
         layout = qt.QVBoxLayout(self)
         layout.setMargin(0)
         layout.setSpacing(0)
         ##############
         self.headerlabel = qt.QLabel(self)
-        self.headerlabel.setAlignment(qt.Qt.AlignHCenter)       
-        self.setheader('<b>Fit of XXXXXXXXXX from X XXXXX to XXXX<\b>')
+        self.headerlabel.setAlignment(qt.Qt.AlignHCenter)
+        self.setHeader('<b>Fit of XXXXXXXXXX from X XXXXX to XXXX<\b>')
         ##############
         if not len(self.specfit.theorylist):
             funsFile = "SpecfitFunctions.py"
             if not os.path.exists(funsFile):
-                funsFile = os.path.join(os.path.dirname(Specfit.__file__),\
-                                funsFile)
+                funsFile = os.path.join(os.path.dirname(Specfit.__file__),
+                                        funsFile)
             self.specfit.importfun(funsFile)
         if 'Area Gaussians' not in self.specfit.theorylist:
             funsFile = "SpecfitFunctions.py"
             if not os.path.exists(funsFile):
-                funsFile = os.path.join(os.path.dirname(Specfit.__file__),\
-                                funsFile)
+                funsFile = os.path.join(os.path.dirname(Specfit.__file__),
+                                        funsFile)
             self.specfit.importfun(funsFile)
         self.specfit.settheory('Area Gaussians')
         self.specfit.setbackground('Linear')
@@ -73,17 +74,19 @@ class ScanFit(qt.QWidget):
         fitconfig['ForcePeakPresence'] = 1
         fitconfig['McaMode']    = 0
         self.specfit.configure(**fitconfig)
-        self.specfitGUI = SpecfitGUI.SpecfitGUI(self,config=1, status=1, buttons=0,
-                                    specfit = self.specfit,eh=self.specfit.eh)
+        self.specfitGUI = SpecfitGUI.SpecfitGUI(self, config=1, status=1,
+                                                buttons=0,
+                                                specfit=self.specfit,
+                                                eh=self.specfit.eh)
         #self.specfitGUI.updateGUI(configuration=fitconfig)
         #self.setdata = self.specfit.setdata
-        
+
         self.specfitGUI.guiconfig.MCACheckBox.setEnabled(1)
         palette = self.specfitGUI.guiconfig.MCACheckBox.palette()
         if QTVERSION < '4.0.0':
             palette.setDisabled(palette.active())
         ##############
-        hbox=qt.QWidget(self)
+        hbox = qt.QWidget(self)
         hboxlayout = qt.QHBoxLayout(hbox)
         hboxlayout.setMargin(0)
         hboxlayout.setSpacing(0)
@@ -97,9 +100,9 @@ class ScanFit(qt.QWidget):
 
         self.dismissbutton = qt.QPushButton(hbox)
         self.dismissbutton.setText("Dismiss")
-        self.connect(self.estimatebutton,qt.SIGNAL("clicked()"),self.estimate)
-        self.connect(self.fitbutton,     qt.SIGNAL("clicked()"),self.fit)
-        self.connect(self.dismissbutton, qt.SIGNAL("clicked()"),self.dismiss)
+        self.connect(self.estimatebutton, qt.SIGNAL("clicked()"), self.estimate)
+        self.connect(self.fitbutton, qt.SIGNAL("clicked()"), self.fit)
+        self.connect(self.dismissbutton, qt.SIGNAL("clicked()"), self.dismiss)
         if QTVERSION < '4.0.0':
             self.connect(self.specfitGUI,
                          qt.PYSIGNAL('SpecfitGUISignal') ,
@@ -114,9 +117,8 @@ class ScanFit(qt.QWidget):
         layout.addWidget(self.specfitGUI)
         layout.addWidget(hbox)
 
-
-    def setData(self,*var,**kw):
-        self.info ={}
+    def setData(self, *var, **kw):
+        self.info = {}
         if 'legend' in kw:
             self.info['legend'] = kw['legend']
             del kw['legend']
@@ -127,7 +129,7 @@ class ScanFit(qt.QWidget):
             del kw['xlabel']
         else:
             self.info['xlabel'] = 'X'
-        self.specfit.setdata(var,**kw)
+        self.specfit.setdata(var, **kw)
         try:
             self.info['xmin'] = "%.3f" % self.specfit.xdata[0]
         except:
@@ -136,12 +138,15 @@ class ScanFit(qt.QWidget):
             self.info['xmax'] = "%.3f" % self.specfit.xdata[-1]
         except:
             self.info['xmax'] = 'Last'
-        self.setheader(text="Fit of %s from %s %s to %s" % (self.info['legend'],
+        self.setHeader(text="Fit of %s from %s %s to %s" % (self.info['legend'],
                                                             self.info['xlabel'],
                                                             self.info['xmin'],
                                                             self.info['xmax']))
 
-    def setheader(self,*var,**kw):
+    def setheader(self, *var, **kw):
+        return self.setHeader(*var, **kw)
+
+    def setHeader(self, *var, **kw):
         if len(var):
             text = var[0]
         elif 'text' in kw:
@@ -168,25 +173,24 @@ class ScanFit(qt.QWidget):
         fitconfig = {}
         fitconfig.update(self.specfit.fitconfig)
         self.specfitGUI.updateGUI(configuration=fitconfig)
-        self.specfitGUI.estimate() 
-    
-    
-    def _specfitGUISignal(self,ddict):
-        if type(ddict) != type({}):
+        self.specfitGUI.estimate()
+
+    def _specfitGUISignal(self, ddict):
+        if not hasattr(ddict, "keys"):
             return
         if 'event' in ddict:
             if ddict['event'].upper() == "PRINT":
                 h = self.__htmlheader()
                 if __name__ == "__main__":
-                    self.__print(h+ddict['text'])
+                    self.__print(h + ddict['text'])
                 else:
-                    ndict={}
+                    ndict = {}
                     ndict['event'] = "ScanFitPrint"
-                    ndict['text' ] = h+ddict['text']
+                    ndict['text' ] = h + ddict['text']
                     ndict['info' ] = {}
                     ndict['info'].update(self.info)
                     if QTVERSION < '4.0.0':
-                        self.emit(qt.PYSIGNAL('ScanFitSignal'),(ndict,))
+                        self.emit(qt.PYSIGNAL('ScanFitSignal'), (ndict,))
                     else:
                         self.emit(qt.SIGNAL('ScanFitSignal'), ndict)
             else:
@@ -195,20 +199,22 @@ class ScanFit(qt.QWidget):
                 ddict['info'] = {}
                 ddict['info'].update(self.info)
                 if QTVERSION < '4.0.0':
-                    self.emit(qt.PYSIGNAL('ScanFitSignal'),(ddict,))
+                    self.emit(qt.PYSIGNAL('ScanFitSignal'), (ddict,))
                 else:
-                    self.emit(qt.SIGNAL('ScanFitSignal'), ddict)    
-        
+                    self.emit(qt.SIGNAL('ScanFitSignal'), ddict)
+
     def dismiss(self):
         self.close()
-        
+
     def __htmlheader(self):
         try:
-            header="Fit of %s from %s %s to %s" % (self.info['legend'],
-                                            self.info['xlabel'],
-                                            self.info['xmin'],
-                                            self.info['xmax'])
+            header = "Fit of %s from %s %s to %s" % (self.info['legend'],
+                                                     self.info['xlabel'],
+                                                     self.info['xmin'],
+                                                     self.info['xmax'])
         except:
+            # I cannot afford any unicode, key or whatever error, so,
+            # provide a default value for the label.
             header = 'Fit of XXXXXXXXXX from Channel XXXXX to XXXX'
         if self.specfit.fitconfig['WeightFlag']:
             weight = "YES"
@@ -222,43 +228,42 @@ class ScanFit(qt.QWidget):
         bkg      = self.specfit.fitconfig['fitbkg']
         fwhm     = self.specfit.fitconfig['FwhmPoints']
         scaling  = self.specfit.fitconfig['Yscaling']
-        h=""
-        h+="    <CENTER>"
-        h+="<B>%s</B>" % header
-        h+="<BR></BR>"
-        h+="<TABLE>"
-        h+="<TR>"
-        h+="    <TD ALIGN=LEFT><B>Function</B></TD>"
-        h+="    <TD><B>:</B></TD>"
-        h+="    <TD ALIGN=LEFT>%s</TD>" % theory
-        h+="    <TD><SPACER TYPE=BLOCK WIDTH=50></TD>"
-        h+="    <TD ALIGN=RIGHT><B>Weight</B></TD>"
-        h+="    <TD><B>:</B></TD>"
-        h+="    <TD ALIGN=LEFT>%s</TD>" % weight
-        h+="    <TD><SPACER TYPE=BLOCK WIDTH=10></B></TD>"
-        h+="    <TD ALIGN=RIGHT><B>FWHM</B></TD>"
-        h+="    <TD><B>:</B></TD></TD>"
-        h+="    <TD ALIGN=LEFT>%d</TD>" % fwhm
-        h+="</TR>"
-        h+="<TR>"
-        h+="    <TD ALIGN=LEFT><B>Background</B></TH>"
-        h+="    <TD><B>:</B></TD>"
-        h+="    <TD ALIGN=LEFT>%s</TD>" % bkg
-        h+="    <TD><SPACER TYPE=BLOCK WIDTH=50></B></TD>"
-        h+="    <TD ALIGN=RIGHT><B>MCA Mode</B></TD>"
-        h+="    <TD><B>:</B></TD>"
-        h+="    <TD ALIGN=LEFT>%s</TD>" % mode
-        h+="    <TD><SPACER TYPE=BLOCK WIDTH=10></B></TD>"
-        h+="    <TD ALIGN=RIGHT><B>Scaling</B></TD>"
-        h+="    <TD><B>:</B></TD>"
-        h+="    <TD ALIGN=LEFT>%g</TD>" % scaling
-        h+="</TR>"
-        h+="</TABLE>"
-        h+="</CENTER>"
+        h = ""
+        h += "    <CENTER>"
+        h += "<B>%s</B>" % header
+        h += "<BR></BR>"
+        h += "<TABLE>"
+        h += "<TR>"
+        h += "    <TD ALIGN=LEFT><B>Function</B></TD>"
+        h += "    <TD><B>:</B></TD>"
+        h += "    <TD ALIGN=LEFT>%s</TD>" % theory
+        h += "    <TD><SPACER TYPE=BLOCK WIDTH=50></TD>"
+        h += "    <TD ALIGN=RIGHT><B>Weight</B></TD>"
+        h += "    <TD><B>:</B></TD>"
+        h += "    <TD ALIGN=LEFT>%s</TD>" % weight
+        h += "    <TD><SPACER TYPE=BLOCK WIDTH=10></B></TD>"
+        h += "    <TD ALIGN=RIGHT><B>FWHM</B></TD>"
+        h += "    <TD><B>:</B></TD></TD>"
+        h += "    <TD ALIGN=LEFT>%d</TD>" % fwhm
+        h += "</TR>"
+        h += "<TR>"
+        h += "    <TD ALIGN=LEFT><B>Background</B></TH>"
+        h += "    <TD><B>:</B></TD>"
+        h += "    <TD ALIGN=LEFT>%s</TD>" % bkg
+        h += "    <TD><SPACER TYPE=BLOCK WIDTH=50></B></TD>"
+        h += "    <TD ALIGN=RIGHT><B>MCA Mode</B></TD>"
+        h += "    <TD><B>:</B></TD>"
+        h += "    <TD ALIGN=LEFT>%s</TD>" % mode
+        h += "    <TD><SPACER TYPE=BLOCK WIDTH=10></B></TD>"
+        h += "    <TD ALIGN=RIGHT><B>Scaling</B></TD>"
+        h += "    <TD><B>:</B></TD>"
+        h += "    <TD ALIGN=LEFT>%g</TD>" % scaling
+        h += "</TR>"
+        h += "</TABLE>"
+        h += "</CENTER>"
         return h
 
-       
-    def __print(self,text):
+    def __print(self, text):
         printer = qt.QPrinter()
         if printer.setup(self):
             painter = qt.QPainter()
@@ -267,19 +272,18 @@ class ScanFit(qt.QWidget):
             try:
                 metrics = qt.QPaintDeviceMetrics(printer)
                 dpiy    = metrics.logicalDpiY()
-                margin  = int((2/2.54) * dpiy) #2cm margin
-                body = qt.QRect(0.5*margin, margin, metrics.width()- 1 * margin, metrics.height() - 2 * margin)
-                #text = self.mcatable.gettext()
-                #html output -> print text
+                margin  = int((2 / 2.54) * dpiy)  # 2cm margin
+                body = qt.QRect(0.5 * margin, margin, metrics.width() - margin,
+                                metrics.height() - 2 * margin)
                 richtext = qt.QSimpleRichText(text, qt.QFont(),
-                                                    qt.QString(""),
-                                                    #0,
-                                                    qt.QStyleSheet.defaultSheet(),
-                                                    qt.QMimeSourceFactory.defaultFactory(),
-                                                    body.height())
+                                              qt.QString(""),
+                                              #0,
+                                              qt.QStyleSheet.defaultSheet(),
+                                              qt.QMimeSourceFactory.defaultFactory(),
+                                              body.height())
                 view = qt.QRect(body)
                 richtext.setWidth(painter,view.width())
-                page = 1                
+                page = 1
                 while(1):
                     richtext.draw(painter,body.left(),body.top(),
                                   view,qt.QColorGroup())
@@ -291,23 +295,23 @@ class ScanFit(qt.QWidget):
                         break
                     printer.newPage()
                     page += 1
-                #painter.flush()
                 painter.end()
             except:
-                #painter.flush()
                 painter.end()
-                msg =  qt.QMessageBox(self)
+                msg = qt.QMessageBox(self)
                 msg.setIcon(qt.QMessageBox.Critical)
                 msg.setText("%s" % sys.exc_info()[1])
                 msg.exec_loop()
 
     def getText(self):
         try:
-            header="Fit of %s from %s %s to %s" % (self.info['legend'],
-                                            self.info['xlabel'],
-                                            self.info['xmin'],
-                                            self.info['xmax'])
+            header = "Fit of %s from %s %s to %s" % (self.info['legend'],
+                                                     self.info['xlabel'],
+                                                     self.info['xmin'],
+                                                     self.info['xmax'])
         except:
+            # I cannot afford any unicode, key or whatever error, so,
+            # provide a default value for the header text.
             header = 'Fit of XXXXXXXXXX from Channel XXXXX to XXXX'
         text = header + "\n"
         if self.specfit.fitconfig['WeightFlag']:
@@ -325,12 +329,11 @@ class ScanFit(qt.QWidget):
         text += "Fit Function: %s\n" % theory
         text += "Background: %s\n" % bkg
         text += "Weight: %s  McaMode: %s  FWHM: %d  Yscaling: %f\n" % (weight[0],
-                                                                     mode[0],
-                                                                     fwhm,
-                                                                     scaling)
+                                                                       mode[0],
+                                                                       fwhm,
+                                                                       scaling)
         text += self.specfitGUI.guiparameters.getText()
-        return  text
-
+        return text
 
     def getConfiguration(self):
         return self.specfit.configure()
@@ -340,7 +343,7 @@ class ScanFit(qt.QWidget):
         self.specfitGUI.updateGUI(configuration=fitconfig)
 
 
-def test():
+def main():
     app = qt.QApplication([])
     w = ScanFit()
     qt.QObject.connect(app, qt.SIGNAL("lasWindowClosed()"),
@@ -353,4 +356,4 @@ def test():
         app.exec_()
 
 if __name__ == "__main__":
-    test()
+    main()
