@@ -1,51 +1,52 @@
 #/*##########################################################################
-# Copyright (C) 2004-2010 European Synchrotron Radiation Facility
+# Copyright (C) 2004-2012 European Synchrotron Radiation Facility
 #
-# This file is part of the PyMCA X-ray Fluorescence Toolkit developed at
-# the ESRF by the Beamline Instrumentation Software Support (BLISS) group.
+# This file is part of the PyMca X-ray Fluorescence Toolkit developed at
+# the ESRF by the Software group.
 #
-# This toolkit is free software; you can redistribute it and/or modify it 
+# This toolkit is free software; you can redistribute it and/or modify it
 # under the terms of the GNU General Public License as published by the Free
-# Software Foundation; either version 2 of the License, or (at your option) 
+# Software Foundation; either version 2 of the License, or (at your option)
 # any later version.
 #
-# PyMCA is distributed in the hope that it will be useful, but WITHOUT ANY
+# PyMca is distributed in the hope that it will be useful, but WITHOUT ANY
 # WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 # FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
 # details.
 #
 # You should have received a copy of the GNU General Public License along with
-# PyMCA; if not, write to the Free Software Foundation, Inc., 59 Temple Place,
-# Suite 330, Boston, MA 02111-1307, USA.
+# PyMca; if not, write to the Free Software Foundation, Inc.,
+# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
-# PyMCA follows the dual licensing model of Trolltech's Qt and Riverbank's PyQt
-# and cannot be used as a free plugin for a non-free program. 
+# PyMca follows the dual licensing model of Riverbank's PyQt and cannot be
+# used as a free plugin for a non-free program.
 #
-# Please contact the ESRF industrial unit (industry@esrf.fr) if this license 
+# Please contact the ESRF industrial unit (industry@esrf.fr) if this license
 # is a problem for you.
 #############################################################################*/
 import sys
 import os
-import SimpleFitModule
-import SimpleFitConfigurationGUI
-import Parameters
-qt = Parameters.qt
+from PyMca import PyMcaQt as qt
+from PyMca import SimpleFitModule
+from PyMca import SimpleFitConfigurationGUI
+from PyMca import SimpleFitUserEstimatedFunctions
+from PyMca import Parameters
 if qt.qVersion() < '4.0.0':
-    raise ImportError, "This module requires PyQt4"
+    raise ImportError("This module requires PyQt4")
 try:
+    #For testing purposes
     #raise ImportError
-    if 1:
-        from QtBlissGraph import QtBlissGraph as GraphWindow
+    if 0:
+        from PyMca.QtBlissGraph import QtBlissGraph as GraphWindow
+    elif 1:
+        from PyMca.Plot1DQwt import Plot1DQwt as GraphWindow
     else:
-        from ScanWindow import ScanWindow as GraphWindow
+        from PyMca.ScanWindow import ScanWindow as GraphWindow
 except ImportError:
-    from Plot1DMatplotlib import Plot1DMatplotlib as GraphWindow
+    from PyMca.Plot1DMatplotlib import Plot1DMatplotlib as GraphWindow
 
 DEBUG = 0
 
-HorizontalSpacer = SimpleFitConfigurationGUI.HorizontalSpacer
-VerticalSpacer = SimpleFitConfigurationGUI.VerticalSpacer
-
 class TopWidget(qt.QWidget):
     def __init__(self, parent=None):
         qt.QWidget.__init__(self, parent)
@@ -67,7 +68,7 @@ class TopWidget(qt.QWidget):
         self.fitFunctionLabel.setFont(font)
         self.fitFunctionLabel.setText("Fit:")
         self.fitFunctionCombo = qt.QComboBox(self)
-        self.fitFunctionCombo.addItem(str("None"))
+        self.fitFunctionCombo.addItem(qt.safe_str("None"))
         self.fitFunctionCombo.setSizeAdjustPolicy(qt.QComboBox.AdjustToContents)
         self.fitFunctionCombo.setMinimumWidth(100)
         
@@ -76,17 +77,17 @@ class TopWidget(qt.QWidget):
         self.backgroundLabel.setFont(font)
         self.backgroundLabel.setText("Background:")
         self.backgroundCombo  = qt.QComboBox(self)
-        self.backgroundCombo.addItem(str("None"))
+        self.backgroundCombo.addItem(qt.safe_str("None"))
         self.backgroundCombo.setSizeAdjustPolicy(qt.QComboBox.AdjustToContents)
         self.backgroundCombo.setMinimumWidth(100)
 
         #arrange everything
         self.mainLayout.addWidget(self.functionLabel,     0, 0)
         self.mainLayout.addWidget(self.addFunctionButton,    0, 1)
-        self.mainLayout.addWidget(HorizontalSpacer(self), 0, 2)
+        self.mainLayout.addWidget(qt.HorizontalSpacer(self), 0, 2)
         self.mainLayout.addWidget(self.fitFunctionLabel,  0, 3)
         self.mainLayout.addWidget(self.fitFunctionCombo,  0, 4)
-        self.mainLayout.addWidget(HorizontalSpacer(self), 0, 5)
+        self.mainLayout.addWidget(qt.HorizontalSpacer(self), 0, 5)
         self.mainLayout.addWidget(self.backgroundLabel,   0, 6)
         self.mainLayout.addWidget(self.backgroundCombo,   0, 7)
 
@@ -95,15 +96,15 @@ class TopWidget(qt.QWidget):
         self.mainLayout.addWidget(self.configureButton,   0, 8)
 
     def setFunctions(self, functionList):
-        currentFunction = str(self.fitFunctionCombo.currentText())
-        currentBackground = str(self.backgroundCombo.currentText())
+        currentFunction = qt.safe_str(self.fitFunctionCombo.currentText())
+        currentBackground = qt.safe_str(self.backgroundCombo.currentText())
         self.fitFunctionCombo.clear()
         self.backgroundCombo.clear()
         self.fitFunctionCombo.addItem('None')
         self.backgroundCombo.addItem('None')
         for key in functionList:
-            self.fitFunctionCombo.addItem(str(key))
-            self.backgroundCombo.addItem(str(key))
+            self.fitFunctionCombo.addItem(qt.safe_str(key))
+            self.backgroundCombo.addItem(qt.safe_str(key))
 
         #restore previous values
         idx = self.fitFunctionCombo.findText(currentFunction)
@@ -119,16 +120,16 @@ class StatusWidget(qt.QWidget):
         self.mainLayout.setSpacing(2)
         
         self.statusLabel = qt.QLabel(self)
-        self.statusLabel.setText(str("Status:"))
+        self.statusLabel.setText(qt.safe_str("Status:"))
         self.statusLine = qt.QLineEdit(self)
-        self.statusLine.setText(str("Ready"))
+        self.statusLine.setText(qt.safe_str("Ready"))
         self.statusLine.setReadOnly(1)
 
         self.chi2Label = qt.QLabel(self)
-        self.chi2Label.setText(str("Reduced Chi Square:"))
+        self.chi2Label.setText(qt.safe_str("Reduced Chi Square:"))
 
         self.chi2Line = qt.QLineEdit(self)
-        self.chi2Line.setText(str(""))
+        self.chi2Line.setText(qt.safe_str(""))
         self.chi2Line.setReadOnly(1)
         
         self.mainLayout.addWidget(self.statusLabel)
@@ -137,11 +138,12 @@ class StatusWidget(qt.QWidget):
         self.mainLayout.addWidget(self.chi2Line)
 
 class SimpleFitGUI(qt.QWidget):
-    def __init__(self, parent=None, fit=None, graph=None):
+    def __init__(self, parent=None, fit=None, graph=None, actions=True):
         qt.QWidget.__init__(self, parent)
         self.setWindowTitle("SimpleFitGUI")
         if fit is None:
             self.fitModule = SimpleFitModule.SimpleFit()
+            self.fitModule.importFunctions(SimpleFitUserEstimatedFunctions)
         else:
             self.fitModule = fit
         if graph is None:
@@ -150,6 +152,10 @@ class SimpleFitGUI(qt.QWidget):
         else:
             self.__useTab = False
             self.graph = graph
+        if hasattr(self.graph, "fitButton"):
+            self.graph.fitButton.hide()
+        if hasattr(self.graph, "scanWindowInfoWidget"):
+            self.graph.scanWindowInfoWidget.hide()
         self._configurationDialog = None
         self.mainLayout = qt.QVBoxLayout(self)
         self.mainLayout.setMargin(2)
@@ -170,27 +176,29 @@ class SimpleFitGUI(qt.QWidget):
 
         self.statusWidget  = StatusWidget(self)
 
-        #build the actions widget
-        self.fitActions = qt.QWidget(self)
-        self.fitActions.mainLayout = qt.QHBoxLayout(self.fitActions)
-        self.fitActions.mainLayout.setMargin(2)
-        self.fitActions.mainLayout.setSpacing(2)
-        self.fitActions.estimateButton = qt.QPushButton(self.fitActions)
-        self.fitActions.estimateButton.setText("Estimate")
-        self.fitActions.startFitButton = qt.QPushButton(self.fitActions)
-        self.fitActions.startFitButton.setText("Start Fit")
-        self.fitActions.dismissButton = qt.QPushButton(self.fitActions)
-        self.fitActions.dismissButton.setText("Dismiss")
-        self.fitActions.mainLayout.addWidget(self.fitActions.estimateButton)
-        self.fitActions.mainLayout.addWidget(self.fitActions.startFitButton)
-        self.fitActions.mainLayout.addWidget(self.fitActions.dismissButton)
         self.mainLayout.addWidget(self.topWidget)
         if self.__useTab:
             self.mainLayout.addWidget(self.mainTab)
         else:
             self.mainLayout.addWidget(self.parametersTable)
         self.mainLayout.addWidget(self.statusWidget)
-        self.mainLayout.addWidget(self.fitActions)
+
+        if actions:
+            #build the actions widget
+            self.fitActions = qt.QWidget(self)
+            self.fitActions.mainLayout = qt.QHBoxLayout(self.fitActions)
+            self.fitActions.mainLayout.setMargin(2)
+            self.fitActions.mainLayout.setSpacing(2)
+            self.fitActions.estimateButton = qt.QPushButton(self.fitActions)
+            self.fitActions.estimateButton.setText("Estimate")
+            self.fitActions.startFitButton = qt.QPushButton(self.fitActions)
+            self.fitActions.startFitButton.setText("Start Fit")
+            self.fitActions.dismissButton = qt.QPushButton(self.fitActions)
+            self.fitActions.dismissButton.setText("Dismiss")
+            self.fitActions.mainLayout.addWidget(self.fitActions.estimateButton)
+            self.fitActions.mainLayout.addWidget(self.fitActions.startFitButton)
+            self.fitActions.mainLayout.addWidget(self.fitActions.dismissButton)
+            self.mainLayout.addWidget(self.fitActions)
 
         #connect top widget
         self.connect(self.topWidget.addFunctionButton,
@@ -208,13 +216,14 @@ class SimpleFitGUI(qt.QWidget):
                      qt.SIGNAL("clicked()"),
                      self.configureButtonSlot)
 
-        #connect actions
-        self.connect(self.fitActions.estimateButton,
-                    qt.SIGNAL("clicked()"),self.estimate)
-        self.connect(self.fitActions.startFitButton,
-                                qt.SIGNAL("clicked()"),self.startFit)
-        self.connect(self.fitActions.dismissButton,
-                                qt.SIGNAL("clicked()"),self.dismiss)        
+        if actions:
+            #connect actions
+            self.connect(self.fitActions.estimateButton,
+                        qt.SIGNAL("clicked()"),self.estimate)
+            self.connect(self.fitActions.startFitButton,
+                                    qt.SIGNAL("clicked()"),self.startFit)
+            self.connect(self.fitActions.dismissButton,
+                                    qt.SIGNAL("clicked()"),self.dismiss)        
 
     def importFunctions(self, functionsfile=None):
         if functionsfile is None:
@@ -222,7 +231,7 @@ class SimpleFitGUI(qt.QWidget):
             if fn.isEmpty():
                 functionsfile = ""
             else:
-                functionsfile= str(fn)
+                functionsfile= qt.safe_str(fn)
             if not len(functionsfile):
                 return
         if DEBUG:
@@ -241,14 +250,14 @@ class SimpleFitGUI(qt.QWidget):
         if idx <= 0:
             fname = "None"
         else:
-            fname = str(self.topWidget.fitFunctionCombo.itemText(idx))
+            fname = qt.safe_str(self.topWidget.fitFunctionCombo.itemText(idx))
         self.fitModule.setFitFunction(fname)
 
     def backgroundComboSlot(self, idx):
         if idx <= 0:
             fname = "None"
         else:
-            fname = str(self.topWidget.backgroundCombo.itemText(idx))
+            fname = qt.safe_str(self.topWidget.backgroundCombo.itemText(idx))
         self.setBackgroundFunction(fname)
 
     def configureButtonSlot(self):
@@ -258,11 +267,12 @@ class SimpleFitGUI(qt.QWidget):
         self._configurationDialog.setSimpleFitInstance(self.fitModule)
         if not self._configurationDialog.exec_():
             if DEBUG:
-                print "NOT UPDATING CONFIGURATION"
+                print("NOT UPDATING CONFIGURATION")
             oldConfig = self.fitModule.getConfiguration()
             self._configurationDialog.setConfiguration(oldConfig)
             return
         newConfig = self._configurationDialog.getConfiguration()
+        self.topWidget.setFunctions(newConfig['fit']['functions'])
         self.fitModule.setConfiguration(newConfig)
         newConfig = self.fitModule.getConfiguration()
         #self.topWidget.setFunctions(newConfig['fit']['functions'])
@@ -279,7 +289,8 @@ class SimpleFitGUI(qt.QWidget):
             idx = newConfig['fit']['functions'].index(fname) + 1
         idx = self.topWidget.backgroundCombo.findText(fname)
         self.topWidget.backgroundCombo.setCurrentIndex(idx)
-        print "TABLE TO BE CLEANED"
+        if DEBUG:
+            print("TABLE TO BE CLEANED")
         #self.estimate()
         
     def setFitFunction(self, fname):
@@ -309,28 +320,33 @@ class SimpleFitGUI(qt.QWidget):
                 self.graph.newCurve('Data',
                                     self.fitModule._x,
                                     self.fitModule._y)
-                self.graph.replot()
+            self.graph.replot()
         return returnValue
 
     def estimate(self):
         self.setStatus("Estimate started")
         self.statusWidget.chi2Line.setText("")
-        if DEBUG:
+        try:
+            x = self.fitModule._x
+            y = self.fitModule._y
+            if hasattr(self.graph, "addCurve"):
+                self.graph.addCurve(x, y, 'Data') 
+            elif hasattr(self.graph, "newCurve"):
+                self.graph.newCurve('Data', x, y) 
+            self.graph.removeCurve("Fit")
+            self.graph.removeCurve("Background", replot=True)
             self.fitModule.estimate()
             self.setStatus()
             self.parametersTable.fillTableFromFit(self.fitModule.paramlist)
-        else:
-            try:
-                self.fitModule.estimate()
-                self.setStatus()
-                self.parametersTable.fillTableFromFit(self.fitModule.paramlist)
-            except:
-                text = "%s:%s" % (sys.exc_info()[0], sys.exc_info()[1])
-                msg = qt.QMessageBox(self)
-                msg.setIcon(qt.QMessageBox.Critical)
-                msg.setText(text)
-                msg.exec_()
-                self.setStatus("Ready (after estimate error)")
+        except:
+            if DEBUG:
+                raise
+            text = "%s:%s" % (sys.exc_info()[0], sys.exc_info()[1])
+            msg = qt.QMessageBox(self)
+            msg.setIcon(qt.QMessageBox.Critical)
+            msg.setText(text)
+            msg.exec_()
+            self.setStatus("Ready (after estimate error)")
             
 
     def setStatus(self, text=None):
@@ -342,21 +358,19 @@ class SimpleFitGUI(qt.QWidget):
     def startFit(self):
         #get parameters from table
         self.fitModule.paramlist = self.parametersTable.fillFitFromTable()
-        if DEBUG:
-            values, chisq, sigma, niter, lastdeltachi = self.fitModule.startFit()
+        try:
+            values,chisq,sigma,niter,lastdeltachi = self.fitModule.startFit()
             self.setStatus()
-        else:
-            try:
-                values,chisq,sigma,niter,lastdeltachi = self.fitModule.startFit()
-                self.setStatus()
-            except:
-                text = "%s:%s" % (sys.exc_info()[0], sys.exc_info()[1])
-                msg = qt.QMessageBox(self)
-                msg.setIcon(qt.QMessageBox.Critical)
-                msg.setText(text)
-                msg.exec_()
-                self.setStatus("Ready (after fit error)")
-                return
+        except:
+            if DEBUG:
+                raise
+            text = "%s:%s" % (sys.exc_info()[0], sys.exc_info()[1])
+            msg = qt.QMessageBox(self)
+            msg.setIcon(qt.QMessageBox.Critical)
+            msg.setText(text)
+            msg.exec_()
+            self.setStatus("Ready (after fit error)")
+            return
             
         self.parametersTable.fillTableFromFit(self.fitModule.paramlist)
         self.statusWidget.chi2Line.setText("%f" % chisq)
@@ -386,7 +400,7 @@ class SimpleFitGUI(qt.QWidget):
             self.graph.newCurve('Data', ddict['x'], ddict['y']) 
             self.graph.newCurve('Fit', ddict['x'], ddict['yfit']) 
             self.graph.newCurve('Background', ddict['x'], ddict['background']) 
-            self.graph.replot()
+        self.graph.replot()
         self.graph.show()
 
     def dismiss(self):
@@ -398,7 +412,7 @@ class SimpleFitGUI(qt.QWidget):
 def test():
     import numpy
     #import DefaultFitFunctions as SpecfitFunctions
-    import SpecfitFunctions
+    from PyMca import SpecfitFunctions
     a=SpecfitFunctions.SpecfitFunctions()
     x = numpy.arange(1000).astype(numpy.float)
     p1 = numpy.array([1500,100.,50.0])
