@@ -1,40 +1,40 @@
 #/*##########################################################################
-# Copyright (C) 2004-2010 European Synchrotron Radiation Facility
+# Copyright (C) 2004-2012 European Synchrotron Radiation Facility
 #
-# This file is part of the PyMCA X-ray Fluorescence Toolkit developed at
-# the ESRF by the Beamline Instrumentation Software Support (BLISS) group.
+# This file is part of the PyMca X-ray Fluorescence Toolkit developed at
+# the ESRF by the Software group.
 #
-# This toolkit is free software; you can redistribute it and/or modify it 
+# This toolkit is free software; you can redistribute it and/or modify it
 # under the terms of the GNU General Public License as published by the Free
-# Software Foundation; either version 2 of the License, or (at your option) 
+# Software Foundation; either version 2 of the License, or (at your option)
 # any later version.
 #
-# PyMCA is distributed in the hope that it will be useful, but WITHOUT ANY
+# PyMca is distributed in the hope that it will be useful, but WITHOUT ANY
 # WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 # FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
 # details.
 #
 # You should have received a copy of the GNU General Public License along with
-# PyMCA; if not, write to the Free Software Foundation, Inc., 59 Temple Place,
-# Suite 330, Boston, MA 02111-1307, USA.
+# PyMca; if not, write to the Free Software Foundation, Inc.,
+# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
-# PyMCA follows the dual licensing model of Trolltech's Qt and Riverbank's PyQt
-# and cannot be used as a free plugin for a non-free program. 
+# PyMca follows the dual licensing model of Riverbank's PyQt and cannot be
+# used as a free plugin for a non-free program.
 #
-# Please contact the ESRF industrial unit (industry@esrf.fr) if this license 
+# Please contact the ESRF industrial unit (industry@esrf.fr) if this license
 # is a problem for you.
 #############################################################################*/
-import numpy
 import sys
 import os
-import types
-import Gefit
-import SpecfitFuns
+import numpy
 import copy
+import types
+from PyMca import Gefit
+from PyMca import SpecfitFuns
 
 DEBUG = 0
 
-class SimpleFit:
+class SimpleFit(object):
     def __init__(self):
         #no data available by default
         self._x0 = None
@@ -86,11 +86,11 @@ class SimpleFit:
         else:
             return self.setConfiguration(ddict)
 
-    def setConfiguration(self, ddict):
+    def setConfiguration(self, ddict, try_import=False):
         oldConfig = self.getConfiguration()
         if ddict is None:
             return oldConfig
-        if ddict.has_key('fit'):
+        if 'fit' in ddict:
             givenKeys = ddict['fit'].keys()
             for key in self._fitConfiguration['fit'].keys():
                 if key in givenKeys:
@@ -100,12 +100,17 @@ class SimpleFit:
                     continue
                 self._fitConfiguration[key] = ddict[key]
 
-        if ddict.has_key('functions'):
+        if 'functions' in ddict:
             functionNames = ddict['functions'].keys()
             for fName in functionNames:
                 if fName not in self._fitConfiguration['functions'].keys():
-                    print "WARNING:Function %s not among defined functions" % fName
-                    continue
+                    if try_import:
+                        ffile = ddict['functions'][fName].get('file', None)
+                        if ffile is not None:
+                            self.importFunctions(ffile)
+                    else:
+                        print("WARNING:Function %s not among defined functions" % fName)
+                        continue
                 self._fitConfiguration['functions'][fName]['configuration']=\
                         ddict['functions'][fName]['configuration']
                 configureMethod = self._fitConfiguration['functions'][fName]\
@@ -119,7 +124,7 @@ class SimpleFit:
         if (oldConfig['fit']['xmin'] != self._fitConfiguration['fit']['xmin']) or\
            (oldConfig['fit']['xmax'] != self._fitConfiguration['fit']['xmax']):
             if DEBUG:
-                print "SETTING DATA AGAIN"
+                print("SETTING DATA AGAIN")
             self.setData(self._x0, self._y0,
                          xmin=self._fitConfiguration['fit']['xmin'],
                          xmax=self._fitConfiguration['fit']['xmax'])
@@ -129,14 +134,14 @@ class SimpleFit:
                     'stripwidth', 'stripiterations', 'stripconstant']:
             if oldConfig['fit'][key] != self._fitConfiguration['fit'][key]:
                 if DEBUG:
-                    print "RECALCULATING STRIP"
+                    print("RECALCULATING STRIP")
                 self._getStripBackground()
                 break
             if key == 'stripanchorsflag':
                 if len(oldConfig['fit']['stripanchorslist']) !=\
                    len(self._fitConfiguration['fit']['stripanchorslist']):
                     if DEBUG:
-                        print "ANCHORS CHANGE, RECALCULATING STRIP"
+                        print("ANCHORS CHANGE, RECALCULATING STRIP")
                     self._getStripBackground()
                     break
 
@@ -163,9 +168,13 @@ class SimpleFit:
             ddict['functions'][key]['parameters'] =  parameters
             widget = self._fitConfiguration['functions'][key]['widget']
             ddict['functions'][key]['widget'] = widget
+            fname = self._fitConfiguration['functions'][key]['file']
+            ddict['functions'][key]['file'] = fname
         return ddict
 
     def setData(self, x, y, sigma=None, xmin=None, xmax=None, **kw):
+        # make sure last fit result is not used
+        self._fitResult = None
         idx = numpy.argsort(x)
         if sigma is not None:
             self._sigma = sigma[idx]
@@ -183,7 +192,8 @@ class SimpleFit:
         self._fitConfiguration['fit']['xmax'] = xmax * 1.0
         if sigma is not None:
             self._sigma = self._sigma0[idx]
-        print "TODO: Make sure we have something to fit"
+        if DEBUG:
+            print("TODO: Make sure we have something to fit")
         #get strip/SNIP background
         self._z = self._getStripBackground()
 
@@ -196,8 +206,8 @@ class SimpleFit:
             f=os.path.basename(os.path.splitext(modname)[0])
             newfun=__import__(f)
         else:
-            raise ValueError, "Cannot interprete/find %s" % modname
-            
+            raise ValueError("Cannot interprete/find %s" % modname)
+        
         theory = newfun.THEORY
         function=newfun.FUNCTION
         parameters = newfun.PARAMETERS
@@ -230,6 +240,7 @@ class SimpleFit:
             ddict['derivative'] = None
             ddict['configure']  = None
             ddict['widget']     = None
+            ddict['file']       = newfun.__file__
             ddict['configuration'] = {} 
             if estimate is not None:
                 ddict['estimate'] = estimate[i]
@@ -253,7 +264,7 @@ class SimpleFit:
         self._fitFunctionConfigured = False
         if name not in self._fitConfiguration['fit']['functions']:
             txt = "Function %s not among defined functions"  % name
-            raise KeyError, txt
+            raise KeyError(txt)
         self._fitConfiguration['fit']['fit_function'] = name
 
     def getFitFunction(self):
@@ -266,7 +277,7 @@ class SimpleFit:
         self._backgroundFunctionConfigured = False
         if name not in self._fitConfiguration['fit']['functions']:
             txt = "Function %s not among defined functions"  % name
-            raise KeyError, txt
+            raise KeyError(txt)
         self._fitConfiguration['fit']['background_function'] = name
 
     def getBackgroundFunction(self):
@@ -320,7 +331,7 @@ class SimpleFit:
         #SNIP algorithm
         if self._fitConfiguration['fit']['stripalgorithm'] in ["SNIP", 1]:
             if DEBUG:
-                print "CALCULATING SNIP"
+                print("CALCULATING SNIP")
             if len(anchorslist) == 0:
                 anchorslist = [0, len(ysmooth)-1]
             anchorslist.sort()
@@ -341,11 +352,13 @@ class SimpleFit:
         niter = self._fitConfiguration['fit']['stripiterations']
         if niter > 0:
             if DEBUG:
-                print "CALCULATING STRIP"
-                print "iterations = ", niter
-                print "constant   = ", self._fitConfiguration['fit']['stripconstant']
-                print "width      = ", self._fitConfiguration['fit']['stripwidth']
-                print "anchors    = ", anchorslist
+                print("CALCULATING STRIP")
+                print("iterations = ", niter)
+                print("constant   = ",
+                      self._fitConfiguration['fit']['stripconstant'])
+                print("width      = ",
+                      self._fitConfiguration['fit']['stripwidth'])
+                print("anchors    = ", anchorslist)
             result=SpecfitFuns.subac(ysmooth,
                                   self._fitConfiguration['fit']['stripconstant'],
                                   niter,
@@ -367,7 +380,7 @@ class SimpleFit:
                                   anchorslist)
         else:
             if DEBUG:
-                print "NO STRIP, NO SNIP"
+                print("NO STRIP, NO SNIP")
             result     = numpy.zeros(ysmooth.shape, numpy.float) + min(ysmooth)
 
         return result
@@ -383,10 +396,11 @@ class SimpleFit:
                     result=SpecfitFuns.SavitskyGolay(numpy.array(y).astype(numpy.float), 
                                     self._fitConfiguration['fit']['stripfilterwidth'])
             else:
-                result=SpecfitFuns.SavitskyGolay(Numeric.array(y).astype(Numeric.Float), 
+                result=SpecfitFuns.SavitskyGolay(numpy.array(y).astype(numpy.float),
                                     self._fitConfiguration['fit']['stripfilterwidth'])
-        except Exception, err:
-            raise "Error", "Unsuccessful Savitsky-Golay smoothing: %s" % err
+        except:
+            err = sys.exc_info()[1]
+            raise ValueError("Unsuccessful Savitsky-Golay smoothing: %s" % err)
             result=numpy.array(y).astype(numpy.float)
         if len(result) > 1:
             result[1:-1]=numpy.convolve(result,f,mode=0)
@@ -427,6 +441,9 @@ class SimpleFit:
                                     self.estimateFunction()
                 fitFunctionDict = self._fitConfiguration['functions']\
                                       [fitFunction]
+        if DEBUG:
+            print("ESTIMATION parameters  = ",functionParameters)
+            print("ESTIMATION constraints = ",functionConstraints)
         self._setStatus("Fit function estimation finished")
 
         #estimations are made
@@ -603,8 +620,8 @@ class SimpleFit:
             weightflag = 0
         else:
             weightflag = 1
-
-        print "STILL TO HANDLE DERIVATIVES"
+        if DEBUG:
+            print("STILL TO HANDLE DERIVATIVES")
         model_deriv = self.modelFunctionDerivative
         if self._fitConfiguration['fit']['strip_flag']:
             y = self._y - self._z
@@ -653,7 +670,7 @@ class SimpleFit:
         self._fitResult['lastdeltachi'] = result[4]
         self._fitResult['n_background_parameters'] = self.__nBackgroundParameters
         if DEBUG:
-            print "Found parameters = ", self._fitResult['fittedvalues']
+            print("Found parameters = ", self._fitResult['fittedvalues'])
         i=0
         self._fitResult['parameters'] = []
         for param in self.paramlist:
@@ -722,7 +739,7 @@ class SimpleFit:
             try:
                 y += self._z
             except:
-                print "Cannot add strip background"
+                print("Cannot add strip background")
         return y
 
     def _evaluateFunction(self, x=None):
@@ -744,7 +761,7 @@ class SimpleFit:
         return y 
 
 def test():
-    import SpecfitFunctions
+    from PyMca import SpecfitFunctions
     a=SpecfitFunctions.SpecfitFunctions()
     x = numpy.arange(1000).astype(numpy.float)
     p1 = numpy.array([1500,100.,50.0])
@@ -759,9 +776,9 @@ def test():
     #fit.setBackgroundFunction('Constant')
     fit.setData(x, y)
     fit.fit()
-    print "Expected parameters 1500,100.,50.0, 1500,700.,50.0"
-    import PyMcaQt as qt
-    import Parameters
+    print("Expected parameters 1500,100.,50.0, 1500,700.,50.0")
+    from PyMca import PyMcaQt as qt
+    from PyMca import Parameters
     a = qt.QApplication(sys.argv)
     qt.QObject.connect(a,qt.SIGNAL("lastWindowClosed()"),a,qt.SLOT("quit()"))
     w =Parameters.Parameters()
