@@ -1,39 +1,37 @@
 #/*##########################################################################
-# Copyright (C) 2004-2010 European Synchrotron Radiation Facility
+# Copyright (C) 2004-2012 European Synchrotron Radiation Facility
 #
-# This file is part of the PyMCA X-ray Fluorescence Toolkit developed at
-# the ESRF by the Beamline Instrumentation Software Support (BLISS) group.
+# This file is part of the PyMca X-ray Fluorescence Toolkit developed at
+# the ESRF by the Software group.
 #
-# This toolkit is free software; you can redistribute it and/or modify it 
+# This toolkit is free software; you can redistribute it and/or modify it
 # under the terms of the GNU General Public License as published by the Free
-# Software Foundation; either version 2 of the License, or (at your option) 
+# Software Foundation; either version 2 of the License, or (at your option)
 # any later version.
 #
-# PyMCA is distributed in the hope that it will be useful, but WITHOUT ANY
+# PyMca is distributed in the hope that it will be useful, but WITHOUT ANY
 # WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 # FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
 # details.
 #
 # You should have received a copy of the GNU General Public License along with
-# PyMCA; if not, write to the Free Software Foundation, Inc., 59 Temple Place,
-# Suite 330, Boston, MA 02111-1307, USA.
+# PyMca; if not, write to the Free Software Foundation, Inc.,
+# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
-# PyMCA follows the dual licensing model of Trolltech's Qt and Riverbank's PyQt
-# and cannot be used as a free plugin for a non-free program. 
+# PyMca follows the dual licensing model of Riverbank's PyQt and cannot be
+# used as a free plugin for a non-free program.
 #
-# Please contact the ESRF industrial unit (industry@esrf.fr) if this license 
+# Please contact the ESRF industrial unit (industry@esrf.fr) if this license
 # is a problem for you.
 #############################################################################*/
-__revision__ = "$Revision: 1.14 $"
-from numpy.oldnumeric import *
-import SpecfitFuns
-import string
+__revision__ = "$Revision: 1.15 $"
 import os
-from Gefit import LeastSquaresFit
+import numpy
+arctan = numpy.arctan
+from PyMca import SpecfitFuns
+from PyMca.Gefit import LeastSquaresFit
 
 DEBUG=0
-if DEBUG:
-    import SimplePlot
 
 try:
     HOME=os.getenv('HOME')
@@ -61,6 +59,7 @@ SPECFITFUNCTIONS_DEFAULTS={'FileAction':0,
                  'FwhmPoints':8,
                  'AutoFwhm':0,
                  'Sensitivity':2.5,
+                 'ForcePeakPresence':0,
                  'McaMode':0,
                  #Hypermet
                  'HypermetTails':15,
@@ -102,7 +101,8 @@ CDELTA      = 5
 CSUM        = 6
 CIGNORED    = 7
 
-class SpecfitFunctions:
+
+class SpecfitFunctions(object):
     def __init__(self,config=None):
         if config is None:
             self.config=SPECFITFUNCTIONS_DEFAULTS
@@ -154,30 +154,51 @@ class SpecfitFunctions:
        return SpecfitFuns.apvoigt(pars,x)
        #return pars[0] + pars [1] * x + SpecfitFuns.apvoigt(pars[2:len(pars)],x)
 
+    def splitgauss(self,pars,x):
+       """
+       Asymmetric gaussian.
+       """
+       return SpecfitFuns.splitgauss(pars,x)
+
+    def splitlorentz(self,pars,x):
+       """
+       Asymmetric lorentz.
+       """
+       return SpecfitFuns.splitlorentz(pars,x)
+
+    def splitpvoigt(self,pars,x):
+       """
+       Asymmetric pseudovoigt.
+       """
+       return SpecfitFuns.splitpvoigt(pars,x)
+
     def stepdown(self,pars,x):
-       """
-       A fit function.
-       """
-       return 0.5*SpecfitFuns.downstep(pars,x)
+        """
+        A fit function.
+        """
+        return 0.5*SpecfitFuns.downstep(pars,x)
 
     def stepup(self,pars,x):
-       """
-       A fit function.
-       """
-       return 0.5*SpecfitFuns.upstep(pars,x)
+        """
+        A fit function.
+        """
+        return 0.5*SpecfitFuns.upstep(pars,x)
 
     def slit(self,pars,x):
-       """
-       A fit function.
-       """
-       return 0.5*SpecfitFuns.slit(pars,x)
+        """
+        A fit function.
+        """
+        return 0.5*SpecfitFuns.slit(pars,x)
+
+    def atan(self, pars, x):
+        return pars[0] * (0.5 + (arctan((1.0*x-pars[1])/pars[2]) / numpy.pi))
 
     def periodic_gauss(self, pars, x):
         """
         Fit function periodic_gauss(pars, x)
         pars = [npeaks, delta, height, position, fwhm]
         """
-        newpars = zeros((pars[0], 3), Float)
+        newpars = numpy.zeros((pars[0], 3), numpy.float)
         for i in range(int(pars[0])):
             newpars[i, 0] = pars[2]
             newpars[i, 1] = pars[3] + i * pars[1]
@@ -185,15 +206,15 @@ class SpecfitFunctions:
         return SpecfitFuns.gauss(newpars,x)
     
     def gauss2(self,param0,t0):
-        param=array(param0)
-        t=array(t0)
+        param=numpy.array(param0)
+        t=numpy.array(t0)
         dummy=2.3548200450309493*(t-param[1])/param[2]
         return param[0] * self.myexp(-0.5 * dummy * dummy)
 
     def myexp(self,x):
         # put a (bad) filter to avoid over/underflows
         # with no python looping
-        return exp(x*less(abs(x),250))-1.0*greater_equal(abs(x),250)
+        return numpy.exp(x * numpy.less(abs(x),250))-1.0*numpy.greater_equal(abs(x),250)
 
     def indexx(x):
         #adapted from runningReport (Mike Fletcher, Python newsgroup) 
@@ -229,21 +250,20 @@ class SpecfitFunctions:
        if nrx == nry:
             return SpecfitFuns.subac(yy,pars[0],pars[1])
        else:
-            return SpecfitFuns.subac(take(yy,arange(0,nry,2)),pars[0],pars[1])
+            return SpecfitFuns.subac(numpy.take(yy,numpy.arange(0,nry,2)),pars[0],pars[1])
             
     def bkg_none(self,pars,x):
        """
        Internal Background
        """       
-       return zeros(x.shape,Float)  
+       return numpy.zeros(x.shape,numpy.float)  
        
     def fun(self,param, t):
-        gterm = param[2] * exp(-0.5 * ((t - param[3]) * (t - param[3]))/param[4])
-        #gterm = gterm + param[3] * exp(-0.5 * ((t - param[4]) * (t - param[4]))/param[5])
+        gterm = param[2] * numpy.exp(-0.5 * ((t - param[3]) * (t - param[3]))/param[4])
+        #gterm = gterm + param[3] * numpy.exp(-0.5 * ((t - param[4]) * (t - param[4]))/param[5])
         bterm = param[1] * t + param[0]
         return gterm + bterm
 
-
     def estimate(self,x,y,z,xscaling=1.0,yscaling=1.0):
         ngauss = input(' Number of Gaussians : ')
         ngauss=int(ngauss)
@@ -251,12 +271,12 @@ class SpecfitFunctions:
             ngauss=1
         newpar=[]
         for i in range(ngauss):
-            print "Defining Gaussian numer %d " % (i+1)
+            print("Defining Gaussian numer %d " % (i+1))
             newpar.append(input('Height   = '))
             newpar.append(input('Position = '))
             newpar.append(input('FWHM     = '))
             #newpar.append(in)
-        return newpar,zeros((3,len(newpar)),Float)
+        return newpar,numpy.zeros((3,len(newpar)),numpy.float)
 
     def seek(self,y,x=None,yscaling=None,
                            fwhm=None,
@@ -288,9 +308,9 @@ class SpecfitFunctions:
         search_sensitivity=max(1.0,sensitivity)
         mca=1.0        
         if mca:
-            ysearch=array(y)*yscaling
+            ysearch = numpy.array(y) * yscaling
         else:
-            ysearch=ones([len(y)+2*search_fwhm,],Float)
+            ysearch = numpy.ones([len(y) + 2 * search_fwhm,], numpy.float)
             if y[0]:
                 ysearch[0:(search_fwhm+1)]=ysearch[0:(search_fwhm+1)]*y[0]*yscaling
             else:
@@ -299,9 +319,9 @@ class SpecfitFunctions:
             ysearch[search_fwhm:(search_fwhm+len(y))]=y*yscaling
         npoints=len(ysearch)
         if npoints > (1.5)*search_fwhm:
-           peaks=SpecfitFuns.seek(ysearch,0,npoints,
+            peaks=SpecfitFuns.seek(ysearch,0,npoints,
                                     search_fwhm,
-                                    search_sensitivity)       
+                                    search_sensitivity)
         else:
             peaks=[]
         
@@ -321,15 +341,15 @@ class SpecfitFunctions:
         return peaks
 
 
-    def guess_fwhm(self,**kw):
-        if kw.has_key('y'):
+    def guess_fwhm(self, **kw):
+        if 'y' in kw:
             y=kw['y']
         else:
             return self.config['FwhmPoints']
-        if kw.has_key('x'):
+        if 'x' in kw:
             x=kw['x']
         else:
-            x=arange(len(y))*1.0
+            x=numpy.arange(len(y))*1.0
 
         #set at least a default value for the fwhm    
         fwhm=4
@@ -338,12 +358,12 @@ class SpecfitFunctions:
         yfit=y-zz
         
         #now I should do some sort of peak search ...
-        maximum=max(yfit)
-        idx=nonzero(yfit == maximum)
-        pos=take(x,idx)[-1]
-        posindex=idx[-1]
-        height=yfit[posindex]
-        imin=posindex
+        maximum = max(yfit)
+        idx = numpy.nonzero(yfit == maximum)[0]
+        pos = numpy.take(x,idx)[-1]
+        posindex = idx[-1]
+        height = yfit[posindex]
+        imin = posindex
         while ((yfit[imin] > 0.5*height) & (imin >0)):
             imin=imin - 1
         imax=posindex
@@ -364,16 +384,14 @@ class SpecfitFunctions:
             yscaling=1.0
        fittedpar=[]
        zz=SpecfitFuns.subac(yy,1.000,10000)
-       if DEBUG:
-            SimplePlot.plot([xx,yy-zz])
        
        npoints = len(zz)
        if self.config['AutoFwhm']:
             search_fwhm=self.guess_fwhm(x=xx,y=yy)
        else: 
-            search_fwhm=int(string.atof(self.config['FwhmPoints']))
-       search_sens=string.atof(self.config['Sensitivity'])
-       search_mca=int(string.atof(self.config['McaMode']))
+            search_fwhm=int(float(self.config['FwhmPoints']))
+       search_sens=float(self.config['Sensitivity'])
+       search_mca=int(float(self.config['McaMode']))
        
        if search_fwhm < 3:
             search_fwhm = 3
@@ -395,6 +413,13 @@ class SpecfitFunctions:
             #                   mca=search_mca)
        else:
             peaks = []
+       if not len(peaks):
+            mca = int(float(self.config.get('McaMode', 0)))
+            forcePeak =  int(float(self.config.get('ForcePeakPresence', 0)))
+            if (not mca) and forcePeak:
+                delta = yy - zz
+                peaks  = [int(numpy.nonzero(delta == delta.max())[0])]
+                
        #print "peaks = ",peaks
        #print "peaks subac = ",self.seek(yy-zz,fwhm=search_fwhm,
        #                        sensitivity=search_sens,
@@ -406,25 +431,28 @@ class SpecfitFunctions:
             for i in peaks:
                 if j == 0:
                     sig=5*abs(xx[npoints-1]-xx[0])/npoints
-                    param = array([yy[int(i)] - zz [int(i)], xx[int(i)] ,sig])
+                    peakpos = xx[int(i)]
+                    if abs(peakpos) < 1.0e-16:
+                        peakpos = 0.0
+                    param = numpy.array([yy[int(i)] - zz[int(i)], peakpos ,sig])
                     largest = param
                 else:
-                    param2 = array([yy[int(i)] - zz [int(i)], xx[int(i)] ,sig])
-                    param = concatenate((param,param2),1)
+                    param2 = numpy.array([yy[int(i)] - zz [int(i)], xx[int(i)] ,sig])
+                    param = numpy.concatenate((param,param2),1)
                     if (param2[0] > largest[0]):
                         largest = param2
                         largest_index = j
                 j = j + 1
-            xw = resize(xx,(npoints,1))
+            xw = numpy.resize(xx,(npoints,1))
             if (0):
-                sy = sqrt(abs(yy))
-                yw = resize(yy-zz,(npoints,1))
-                sy = resize(sy,(npoints,1))
-                datawork = concatenate((xw,yw,sy),1)
+                sy = numpy.sqrt(abs(yy))
+                yw = numpy.resize(yy-zz,(npoints,1))
+                sy = numpy.resize(sy,(npoints,1))
+                datawork = numpy.concatenate((xw,yw,sy),1)
             else:
-                yw = resize(yy-zz,(npoints,1))
-                datawork = concatenate((xw,yw),1)            
-            cons = zeros((3,len(param)),Float)
+                yw = numpy.resize(yy-zz,(npoints,1))
+                datawork = numpy.concatenate((xw,yw),1)            
+            cons = numpy.zeros((3,len(param)),numpy.float)
             cons [0] [0:len(param):3] = CPOSITIVE
             #force peaks to stay around their position
             if (1):
@@ -434,12 +462,12 @@ class SpecfitFunctions:
                 #cons [1] [1:len(param):3] = param[1:len(param):3]-0.5*search_fwhm
                 #cons [2] [1:len(param):3] = param[1:len(param):3]+0.5*search_fwhm                
                 if len(xw) > search_fwhm:
-                    fwhmx=fabs(xw[int(search_fwhm)]-xw[0])
+                    fwhmx = numpy.fabs(xw[int(search_fwhm)]-xw[0])
                     cons [1] [1:len(param):3] = param[1:len(param):3]-0.5*fwhmx
                     cons [2] [1:len(param):3] = param[1:len(param):3]+0.5*fwhmx                
                 else:
-                    cons [1] [1:len(param):3] = ones(shape(param[1:len(param):3]),Float)*min(xw)
-                    cons [2] [1:len(param):3] = ones(shape(param[1:len(param):3]),Float)*max(xw)            
+                    cons [1] [1:len(param):3] = numpy.ones(shape(param[1:len(param):3]),numpy.float)*min(xw)
+                    cons [2] [1:len(param):3] = numpy.ones(shape(param[1:len(param):3]),numpy.float)*max(xw)            
 
             if 0:
                 cons [0] [2:len(param):3] = CFACTOR
@@ -467,14 +495,14 @@ class SpecfitFunctions:
        #     peakpos,height,myidx = SpecArithmetic.search_peak(xx,yy-zz)
        #     fwhm,cfwhm         = SpecArithmetic.search_fwhm(xx,yy-zz,
        #                                    peak=peakpos,index=myidx) 
-       #     xx = array(xx)
+       #     xx = numpy.array(xx)
        #     if npoints > 2:
        #         #forget SPEC estimation of fwhm
        #         fwhm=5*abs(xx[npoints-1]-xx[0])/npoints
        #     fittedpar=[height,peakpos,fwhm]
-       #     largest=array([height,peakpos,fwhm])
+       #     largest=numpy.array([height,peakpos,fwhm])
        #     peaks=[peakpos]
-       cons = zeros((3,len(fittedpar)),Float)
+       cons = numpy.zeros((3,len(fittedpar)),numpy.float)
        j=0
        for i in range(len(peaks)):
                 #Setup height area constrains
@@ -517,30 +545,86 @@ class SpecfitFunctions:
        return  fittedpar,cons
 
     def estimate_agauss(self,xx,yy,zzz,xscaling=1.0,yscaling=None):
-       fittedpar,cons = self.estimate_gauss(xx,yy,zzz,xscaling,yscaling)
-       #get the number of found peaks
-       npeaks=len(cons[0])/3
-       for i in range(npeaks):
+        fittedpar,cons = self.estimate_gauss(xx,yy,zzz,xscaling,yscaling)
+        #get the number of found peaks
+        npeaks=int(len(cons[0])/3)
+        for i in range(npeaks):
             height = fittedpar[3*i]
             fwhm = fittedpar[3*i+2]
-            fittedpar[3*i] = (height * fwhm / (2.0*sqrt(2*log(2))))*sqrt(2*pi)
-       return fittedpar,cons
+            fittedpar[3*i] = (height * fwhm / (2.0*numpy.sqrt(2*numpy.log(2))))*numpy.sqrt(2 * numpy.pi)
+        return fittedpar,cons
 
     def estimate_alorentz(self,xx,yy,zzz,xscaling=1.0,yscaling=None):
-       fittedpar,cons = self.estimate_gauss(xx,yy,zzz,xscaling,yscaling)
-       #get the number of found peaks
-       npeaks=len(cons[0])/3
-       for i in range(npeaks):
+        fittedpar,cons = self.estimate_gauss(xx,yy,zzz,xscaling,yscaling)
+        #get the number of found peaks
+        npeaks=int(len(cons[0])/3)
+        for i in range(npeaks):
             height = fittedpar[3*i]
             fwhm = fittedpar[3*i+2]
-            fittedpar[3*i] = (height * fwhm * 0.5 *pi)
-       return fittedpar,cons
+            fittedpar[3*i] = (height * fwhm * 0.5 * numpy.pi)
+        return fittedpar,cons
+
+    def estimate_splitgauss(self,xx,yy,zzz,xscaling=1.0,yscaling=None):
+        fittedpar, cons = self.estimate_gauss(xx,yy,zzz,xscaling,yscaling)
+        #get the number of found peaks
+        npeaks=int(len(cons[0])/3)
+        estimated_parameters = []
+        estimated_constraints = numpy.zeros((3, 4*npeaks),numpy.float)
+        for i in range(npeaks):
+            for j in range(3):
+                estimated_parameters.append(fittedpar[3*i+j])
+            estimated_parameters.append(fittedpar[3*i+2])
+            estimated_constraints[0][4*i]   = cons [0][3*i]
+            estimated_constraints[0][4*i+1] = cons [0][3*i+1]
+            estimated_constraints[0][4*i+2] = cons [0][3*i+2]
+            estimated_constraints[0][4*i+3] = cons [0][3*i+2]
+            estimated_constraints[1][4*i]   = cons [1][3*i]
+            estimated_constraints[1][4*i+1] = cons [1][3*i+1]
+            estimated_constraints[1][4*i+2] = cons [1][3*i+2]
+            estimated_constraints[1][4*i+3] = cons [1][3*i+2]
+            estimated_constraints[2][4*i]   = cons [2][3*i]
+            estimated_constraints[2][4*i+1] = cons [2][3*i+1]
+            estimated_constraints[2][4*i+2] = cons [2][3*i+2]
+            estimated_constraints[2][4*i+3] = cons [2][3*i+2]
+            if cons[0][3*i+2] == 4:
+                #same FWHM case
+                estimated_constraints[1][4*i+2] = int(cons[1][3*i+2]/3) * 4 + 2
+                estimated_constraints[1][4*i+3] = int(cons[1][3*i+2]/3) * 4 + 3         
+        return estimated_parameters, estimated_constraints
+        
+    def estimate_splitlorentz(self,xx,yy,zzz,xscaling=1.0,yscaling=None):
+        fittedpar, cons = self.estimate_gauss(xx,yy,zzz,xscaling,yscaling)
+        #get the number of found peaks
+        npeaks=int(len(cons[0])/3)
+        estimated_parameters = []
+        estimated_constraints = numpy.zeros((3, 4*npeaks),numpy.float)
+        for i in range(npeaks):
+            for j in range(3):
+                estimated_parameters.append(fittedpar[3*i+j])
+            estimated_parameters.append(fittedpar[3*i+2])
+            estimated_constraints[0][4*i]   = cons [0][3*i]
+            estimated_constraints[0][4*i+1] = cons [0][3*i+1]
+            estimated_constraints[0][4*i+2] = cons [0][3*i+2]
+            estimated_constraints[0][4*i+3] = cons [0][3*i+2]
+            estimated_constraints[1][4*i]   = cons [1][3*i]
+            estimated_constraints[1][4*i+1] = cons [1][3*i+1]
+            estimated_constraints[1][4*i+2] = cons [1][3*i+2]
+            estimated_constraints[1][4*i+3] = cons [1][3*i+2]
+            estimated_constraints[2][4*i]   = cons [2][3*i]
+            estimated_constraints[2][4*i+1] = cons [2][3*i+1]
+            estimated_constraints[2][4*i+2] = cons [2][3*i+2]
+            estimated_constraints[2][4*i+3] = cons [2][3*i+2]
+            if cons[0][3*i+2] == 4:
+                #same FWHM case
+                estimated_constraints[1][4*i+2] = int(cons[1][3*i+2]/3) * 4 + 2
+                estimated_constraints[1][4*i+3] = int(cons[1][3*i+2]/3) * 4 + 3         
+        return estimated_parameters, estimated_constraints
        
     def estimate_pvoigt(self,xx,yy,zzz,xscaling=1.0,yscaling=None):
        fittedpar,cons = self.estimate_gauss(xx,yy,zzz,xscaling,yscaling)
-       npeaks=len(cons[0])/3
+       npeaks=int(len(cons[0])/3)
        newpar=[]
-       newcons=zeros((3,4*npeaks),Float)
+       newcons=numpy.zeros((3,4*npeaks),numpy.float)
        #find out related parameters proper index
        if self.config['NoConstrainsFlag'] == 0:
             if self.config['SameFwhmFlag']:
@@ -578,14 +662,67 @@ class SpecfitFunctions:
                       newcons[2][4*i+3]=1.0
        return  newpar,newcons
 
+    def estimate_splitpvoigt(self,xx,yy,zzz,xscaling=1.0,yscaling=None):
+       fittedpar,cons = self.estimate_gauss(xx,yy,zzz,xscaling,yscaling)
+       npeaks=int(len(cons[0])/3)
+       newpar=[]
+       newcons=numpy.zeros((3,5*npeaks),numpy.float)
+       #find out related parameters proper index
+       if self.config['NoConstrainsFlag'] == 0:
+            if self.config['SameFwhmFlag']:
+                j=0
+                #get the index of the free FWHM
+                for i in range(npeaks):
+                    if cons[0][3*i+2] != 4:
+                        j=i
+                for i in range(npeaks):
+                    if i != j:
+                       cons[1][3*i+2] = 4*j+2 
+       for i in range(npeaks):
+            #height
+            newpar.append(fittedpar[3*i])
+            #position
+            newpar.append(fittedpar[3*i+1])
+            #fwhm1
+            newpar.append(fittedpar[3*i+2])
+            #fwhm2 equal to the first
+            newpar.append(fittedpar[3*i+2])
+            #eta
+            newpar.append(0.5)
+            newcons[0][5*i]=cons[0][3*i]
+            newcons[0][5*i+1]=cons[0][3*i+1]
+            newcons[0][5*i+2]=cons[0][3*i+2]
+            newcons[0][5*i+3]=cons[0][3*i+2]
+            newcons[1][5*i]=cons[1][3*i]
+            newcons[1][5*i+1]=cons[1][3*i+1]
+            newcons[1][5*i+2]=cons[1][3*i+2]
+            newcons[1][5*i+3]=cons[1][3*i+2]
+            newcons[2][5*i]=cons[2][3*i]
+            newcons[2][5*i+1]=cons[2][3*i+1]
+            newcons[2][5*i+2]=cons[2][3*i+2]
+            newcons[2][5*i+3]=cons[2][3*i+2]
+            if cons[0][3*i+2] == 4:
+                newcons[1][5*i+3] = newcons[1][5*i+2]+1                
+            #Eta constrains
+            newcons[0][5*i+4]=0
+            newcons[1][5*i+4]=0
+            newcons[2][5*i+4]=0
+            if self.config['NoConstrainsFlag'] == 0:
+                if self.config['EtaFlag']:
+                      #QUOTED=2
+                      newcons[0][5*i+4]=2
+                      newcons[1][5*i+4]=0.0              
+                      newcons[2][5*i+4]=1.0
+       return  newpar,newcons
+
     def estimate_apvoigt(self,xx,yy,zzz,xscaling=1.0,yscaling=None):
        fittedpar,cons = self.estimate_pvoigt(xx,yy,zzz,xscaling,yscaling)
-       npeaks=len(cons[0])/4
+       npeaks=int(len(cons[0])/4)
        for i in range(npeaks):
             height = fittedpar[4*i]
             fwhm = fittedpar[4*i+2]
-            fittedpar[4*i] = 0.5*(height * fwhm * 0.5 *pi)+\
-                         0.5*(height * fwhm / (2.0*sqrt(2*log(2))))*sqrt(2*pi)
+            fittedpar[4*i] = 0.5*(height * fwhm * 0.5 * numpy.pi)+\
+                         0.5*(height * fwhm / (2.0*numpy.sqrt(2*numpy.log(2))))* numpy.sqrt(2 * numpy.pi)
        return fittedpar,cons
        
     def estimate_hypermet(self,xx,yy,zzz,xscaling=1.0,yscaling=None):
@@ -599,9 +736,9 @@ class SpecfitFunctions:
             yscaling=1.0
        """ 
        fittedpar,cons = self.estimate_gauss(xx,yy,zzz,xscaling,yscaling)
-       npeaks=len(cons[0])/3
+       npeaks=int(len(cons[0])/3)
        newpar=[]
-       newcons=zeros((3,8*npeaks),Float)
+       newcons=numpy.zeros((3,8*npeaks),numpy.float)
        main_peak=0
        #find out related parameters proper index
        if self.config['NoConstrainsFlag'] == 0:
@@ -623,7 +760,7 @@ class SpecfitFunctions:
             height = fittedpar[3*i]
             position=fittedpar[3*i+1]
             fwhm = fittedpar[3*i+2]
-            area = (height * fwhm / (2.0*sqrt(2*log(2))))*sqrt(2*pi)
+            area = (height * fwhm / (2.0*numpy.sqrt(2*numpy.log(2))))*numpy.sqrt(2 * numpy.pi)
             #the gaussian parameters
             newpar.append(area)
             newpar.append(position)
@@ -710,7 +847,7 @@ class SpecfitFunctions:
                newcons[1][8*i+7]=self.config['MinStepTailHeightRatio']
                newcons[2][8*i+7]=self.config['MaxStepTailHeightRatio']
             #if self.config['NoConstrainsFlag'] == 1:
-            #   newcons=zeros((3,8*npeaks),Float)
+            #   newcons=numpy.zeros((3,8*npeaks),numpy.float)
        if npeaks > 0:
           if g_term:
             if self.config['HeightAreaFlag']:
@@ -728,7 +865,7 @@ class SpecfitFunctions:
             if self.config['QuotedPositionFlag']:
                 for i in range(npeaks):
                     delta=self.config['DeltaPositionFwhmUnits'] * \
-                      int(string.atof(self.config['FwhmPoints']))
+                      int(float(self.config['FwhmPoints']))
                     #that was delta in points
                     #I need it in terms of FWHM
                     delta=self.config['DeltaPositionFwhmUnits'] * fwhm
@@ -758,17 +895,17 @@ class SpecfitFunctions:
     def estimate_stepdown(self,xxx,yyy,zzz,xscaling=1.0,yscaling=1.0):
         crappyfilter=[-0.25,-0.75,0.0,0.75,0.25]
         cutoff = 2
-        yy=convolve(yyy,crappyfilter,mode=1)[2:-2]
+        yy = numpy.convolve(yyy, crappyfilter, mode=1)[2:-2]
         if max(yy) > 0:
             yy = yy * max(yyy)/max(yy)
         xx=xxx[2:-2]
         fittedpar,cons=self.estimate_agauss(xx,yy,zzz,xscaling,yscaling)
-        npeaks=len(cons[0])/4
+        npeaks=int(len(cons[0])/4)
         largest_index=0
         largest=[fittedpar[3*largest_index],
                  fittedpar[3*largest_index+1],
                  fittedpar[3*largest_index+2]]
-        newcons=zeros((3,3),Float)
+        newcons=numpy.zeros((3,3),numpy.float)
         for i in range(npeaks):
             if fittedpar[3*i] > largest[0]:
                 largest_index=i
@@ -801,24 +938,24 @@ class SpecfitFunctions:
                         
         return largest,cons
     
-    def estimate_slit(self,xxx,yyy,zzz,xscaling=1.0,yscaling=1.0):
-        largestup,cons=self.estimate_stepup(xxx,yyy,zzz,xscaling,yscaling)
-        largestdown,cons=self.estimate_stepdown(xxx,yyy,zzz,xscaling,yscaling)
-        height=0.5*(largestup[0]+largestdown[0])
-        position=0.5*(largestup[1]+largestdown[1])
-        fwhm=fabs(largestdown[1]-largestup[1])
-        beamfwhm=0.5*(largestup[2]+largestdown[1])
-        beamfwhm=min(beamfwhm,fwhm/10.0)
-        beamfwhm=max(beamfwhm,(max(xxx)-min(xxx))*3.0/len(xxx))
+    def estimate_slit(self, xxx, yyy, zzz, xscaling=1.0, yscaling=1.0):
+        largestup, cons = self.estimate_stepup(xxx, yyy, zzz, xscaling, yscaling)
+        largestdown, cons = self.estimate_stepdown(xxx, yyy, zzz, xscaling, yscaling)
+        height = 0.5*(largestup[0] + largestdown[0])
+        position = 0.5*(largestup[1] + largestdown[1])
+        fwhm = numpy.fabs(largestdown[1] - largestup[1])
+        beamfwhm = 0.5 * (largestup[2] + largestdown[1])
+        beamfwhm = min(beamfwhm, fwhm / 10.0)
+        beamfwhm = max(beamfwhm,(max(xxx)-min(xxx))*3.0/len(xxx))
         #own estimation
         yy=yyy-zzz
         height=max(yyy-zzz)
-        i1=nonzero(yy>=0.5*height)
-        xx=take(xxx,i1)
+        i1=numpy.nonzero(yy>=0.5*height)[0]
+        xx=numpy.take(xxx,i1)
         position=(xx[0]+xx[-1])/2.0
         fwhm=xx[-1]-xx[0]       
         largest=[height,position,fwhm,beamfwhm]
-        cons=zeros((3,4),Float)
+        cons=numpy.zeros((3,4),numpy.float)
         #Setup constrains
         if self.config['NoConstrainsFlag'] == 0:
                 #Setup height constrains
@@ -850,20 +987,20 @@ class SpecfitFunctions:
                                 cons[2][3]=0                        
         return largest,cons
         
-    def estimate_stepup(self,xxx,yyy,zzz,xscaling=1.0,yscaling=1.0):
-        crappyfilter=[0.25,0.75,0.0,-0.75,-0.25]
+    def estimate_stepup(self, xxx, yyy, zzz, xscaling=1.0, yscaling=1.0):
+        crappyfilter = [0.25, 0.75, 0.0, -0.75, -0.25]
         cutoff = 2
-        yy=convolve(yyy,crappyfilter,mode=1)[2:-2]
+        yy = numpy.convolve(yyy, crappyfilter, mode=1)[2:-2]
         if max(yy) > 0:
             yy = yy * max(yyy)/max(yy)
-        xx=xxx[2:-2]
-        fittedpar,cons=self.estimate_agauss(xx,yy,zzz,xscaling,yscaling)
-        npeaks=len(cons[0])/4
-        largest_index=0
-        largest=[fittedpar[3*largest_index],
-                 fittedpar[3*largest_index+1],
-                 fittedpar[3*largest_index+2]]
-        newcons=zeros((3,3),Float)
+        xx = xxx[2:-2]
+        fittedpar, cons = self.estimate_agauss(xx, yy, zzz, xscaling, yscaling)
+        npeaks = int(len(cons[0]) / 4)
+        largest_index = 0
+        largest = [fittedpar[3 * largest_index],
+                   fittedpar[3 * largest_index + 1],
+                   fittedpar[3 * largest_index + 2]]
+        newcons=numpy.zeros((3,3),numpy.float)
         for i in range(npeaks):
             if fittedpar[3*i] > largest[0]:
                 largest_index=i
@@ -896,6 +1033,9 @@ class SpecfitFunctions:
                         
         return largest,cons
 
+    def estimate_atan(self, *var, **kw):
+        return self.estimate_stepup(*var, **kw)
+
     def estimate_periodic_gauss(self,xx,yy,zzz,xscaling=1.0,yscaling=None):
         if yscaling == None:
             try:
@@ -911,9 +1051,9 @@ class SpecfitFunctions:
         if self.config['AutoFwhm']:
             search_fwhm=self.guess_fwhm(x=xx,y=yy)
         else: 
-            search_fwhm=int(string.atof(self.config['FwhmPoints']))
-        search_sens=string.atof(self.config['Sensitivity'])
-        search_mca=int(string.atof(self.config['McaMode']))
+            search_fwhm=int(float(self.config['FwhmPoints']))
+        search_sens=float(self.config['Sensitivity'])
+        search_mca=int(float(self.config['McaMode']))
        
         if search_fwhm < 3:
             search_fwhm = 3
@@ -933,7 +1073,7 @@ class SpecfitFunctions:
         npeaks = len(peaks)
         if not npeaks:
             fittedpar = []
-            cons = zeros((3,len(fittedpar)), Float)
+            cons = numpy.zeros((3,len(fittedpar)), numpy.float)
             return fittedpar, cons
 
         fittedpar = [0.0, 0.0, 0.0, 0.0, 0.0]
@@ -963,7 +1103,7 @@ class SpecfitFunctions:
         fittedpar[4] = search_fwhm
 
         #setup constraints
-        cons = zeros((3, 5), Float)
+        cons = numpy.zeros((3, 5), numpy.float)
         cons [0] [0] = CFIXED     #the number of gaussians
         if npeaks == 1:
             cons[0][1] = CFIXED  #the delta between peaks
@@ -1006,7 +1146,7 @@ class SpecfitFunctions:
             notdone=1
             #take care of lower / upper case problems ...
             for config_key in self.config.keys():
-                if string.lower(config_key) == string.lower(key):
+                if config_key.lower() == key.lower():
                     self.config[config_key] = kw[key]
                     notdone=0
             if notdone:
@@ -1021,9 +1161,13 @@ FUNCTION=[fitfuns.gauss,
           fitfuns.alorentz,
           fitfuns.pvoigt,
           fitfuns.apvoigt,
+          fitfuns.splitgauss,
+          fitfuns.splitlorentz,
+          fitfuns.splitpvoigt,
           fitfuns.stepdown,
           fitfuns.stepup,
           fitfuns.slit,
+          fitfuns.atan,
           fitfuns.hypermet,
           fitfuns.periodic_gauss]
           
@@ -1033,9 +1177,13 @@ PARAMETERS=[['Height','Position','FWHM'],
             ['Area','Position','Fwhm'],
             ['Height','Position','Fwhm','Eta'],
             ['Area','Position','Fwhm','Eta'],
+            ['Height','Position','LowFWHM', 'HighFWHM'],
+            ['Height','Position','LowFWHM', 'HighFWHM'],
+            ['Height','Position','LowFWHM', 'HighFWHM', 'Eta'],
             ['Height','Position','FWHM'],
             ['Height','Position','FWHM'],
             ['Height','Position','FWHM','BeamFWHM'],
+            ['Height','Position','Width'],
             ['G_Area','Position','FWHM',
              'ST_Area','ST_Slope','LT_Area','LT_Slope','Step_H'],
             ['N', 'Delta', 'Height', 'Position', 'FWHM']]
@@ -1046,9 +1194,13 @@ THEORY=['Gaussians',
         'Area Lorentz',
         'Pseudo-Voigt Line',
         'Area Pseudo-Voigt',
+        'Split Gaussian',
+        'Split Lorentz',
+        'Split Pseudo-Voigt',
         'Step Down',
         'Step Up',
         'Slit',
+        'Atan',
         'Hypermet',
         'Periodic Gaussians']
 
@@ -1058,9 +1210,13 @@ ESTIMATE=[fitfuns.estimate_gauss,
           fitfuns.estimate_alorentz,
           fitfuns.estimate_pvoigt,
           fitfuns.estimate_apvoigt,
+          fitfuns.estimate_splitgauss,
+          fitfuns.estimate_splitlorentz,
+          fitfuns.estimate_splitpvoigt,
           fitfuns.estimate_stepdown,
           fitfuns.estimate_stepup,
           fitfuns.estimate_slit,
+          fitfuns.estimate_atan,
           fitfuns.estimate_hypermet,
           fitfuns.estimate_periodic_gauss]
 
@@ -1074,25 +1230,29 @@ CONFIGURE=[fitfuns.configure,
            fitfuns.configure,
            fitfuns.configure,
            fitfuns.configure,
+           fitfuns.configure,
+           fitfuns.configure,
+           fitfuns.configure,
+           fitfuns.configure,
            fitfuns.configure]
 
 def test(a):
-    import Tkinter
-    import NewSpecfit
-    import SimplePlot
+    from PyMca import PyMcaQt as qt
+    from PyMca import Specfit
+    from PyMca import ScanWindow
     #print dir(a)
-    x = arange(1000).astype(Float)
-    p1 = array([1500,100.,50.0])
-    p2 = array([1500,700.,50.0])
+    x = numpy.arange(1000).astype(numpy.float)
+    p1 = numpy.array([1500,100.,50.0])
+    p2 = numpy.array([1500,700.,50.0])
     y = a.gauss(p1,x)+1
     y = y + a.gauss(p2,x)
-    root=Tkinter.Tk()
+    app=qt.QApplication([])
     #fit=Specfit.Specfit(root,x,y,
     #                    user_theory='New Theory',
     #                    user_function=a.gauss,
     #                    user_parameters=['Height','Position','FWHM'])
     #                    #user_estimate=estimate)
-    fit=NewSpecfit.Specfit(x,y)
+    fit=Specfit.Specfit(x,y)
     fit.addtheory('Gaussians',a.gauss,['Height','Position','FWHM'],
                     a.estimate_gauss)                       
     fit.settheory('Gaussians')
@@ -1101,9 +1261,12 @@ def test(a):
     fit.estimate()
     fit.startfit()
     yfit=fit.gendata(x=x,parameters=fit.paramlist)
-    print "I set an offset of 1 to see the difference in log scale :-)"
-    SimplePlot.plot([x,y+1,yfit])
-    root.mainloop()
+    print("I set an offset of 1 to see the difference in log scale :-)")
+    w = ScanWindow.ScanWindow()
+    w.addCurve(x, y + 1, "Data + 1")
+    w.addCurve(x, yfit, "Fit")
+    w.show()
+    app.exec_()
 
           
 if __name__ == "__main__":
