@@ -1,45 +1,43 @@
 #/*##########################################################################
-# Copyright (C) 2004-2009 European Synchrotron Radiation Facility
+# Copyright (C) 2004-2012 European Synchrotron Radiation Facility
 #
-# This file is part of the PyMCA X-ray Fluorescence Toolkit developed at
-# the ESRF by the Beamline Instrumentation Software Support (BLISS) group.
+# This file is part of the PyMca X-ray Fluorescence Toolkit developed at
+# the ESRF by the Software group.
 #
-# This toolkit is free software; you can redistribute it and/or modify it 
+# This toolkit is free software; you can redistribute it and/or modify it
 # under the terms of the GNU General Public License as published by the Free
-# Software Foundation; either version 2 of the License, or (at your option) 
+# Software Foundation; either version 2 of the License, or (at your option)
 # any later version.
 #
-# PyMCA is distributed in the hope that it will be useful, but WITHOUT ANY
+# PyMca is distributed in the hope that it will be useful, but WITHOUT ANY
 # WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 # FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
 # details.
 #
 # You should have received a copy of the GNU General Public License along with
-# PyMCA; if not, write to the Free Software Foundation, Inc., 59 Temple Place,
-# Suite 330, Boston, MA 02111-1307, USA.
+# PyMca; if not, write to the Free Software Foundation, Inc.,
+# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
-# PyMCA follows the dual licensing model of Trolltech's Qt and Riverbank's PyQt
-# and cannot be used as a free plugin for a non-free program. 
+# PyMca follows the dual licensing model of Riverbank's PyQt and cannot be
+# used as a free plugin for a non-free program.
 #
-# Please contact the ESRF industrial unit (industry@esrf.fr) if this license 
+# Please contact the ESRF industrial unit (industry@esrf.fr) if this license
 # is a problem for you.
 #############################################################################*/
-import EventHandler
-import Specfit
 import sys
-
-import PyMcaQt as qt
+import os
+from PyMca import EventHandler
+from PyMca import Specfit
+from PyMca import PyMcaQt as qt
     
 QTVERSION = qt.qVersion()
-import FitConfigGUI
-import MultiParameters
-import FitActionsGUI
-import FitStatusGUI
-import EventHandler
-if 1 or QTVERSION < '4.0.0':
-    import QScriptOption
-else:
-    print "QScriptOption not ported yet"
+from PyMca import FitConfigGUI
+from PyMca import MultiParameters
+from PyMca import FitActionsGUI
+from PyMca import FitStatusGUI
+from PyMca import EventHandler
+from PyMca import QScriptOption
+DEBUG = 0
 
 class SpecfitGUI(qt.QWidget):
     def __init__(self,parent = None,name = None,fl = 0, specfit = None,
@@ -58,9 +56,17 @@ class SpecfitGUI(qt.QWidget):
             self.eh = eh
         if specfit is None:
             self.specfit = Specfit.Specfit(eh=self.eh)
-            self.specfit.importfun("SpecfitFunctions.py")
         else:
             self.specfit = specfit
+
+        #initialize the default fitting functions in case
+        #none is present
+        if not len(self.specfit.theorylist):
+            funsFile = "SpecfitFunctions.py"
+            if not os.path.exists(funsFile):
+                funsFile = os.path.join(os.path.dirname(Specfit.__file__),\
+                                funsFile)
+            self.specfit.importfun(funsFile)
         
         #copy specfit configure method for direct access
         self.configure=self.specfit.configure
@@ -112,15 +118,19 @@ class SpecfitGUI(qt.QWidget):
             if specfit is not None:
                 configuration = specfit.configure()
                 if configuration['fittheory'] is None:
-                    if QTVERSION < '4.0.0': self.guiconfig.FunComBox.setCurrentItem(1)
-                    else:  self.guiconfig.FunComBox.setCurrentIndex(1)
+                    if QTVERSION < '4.0.0':
+                        self.guiconfig.FunComBox.setCurrentItem(1)
+                    else:
+                        self.guiconfig.FunComBox.setCurrentIndex(1)
                     self.funevent(self.specfit.theorylist[0])
                 else:
                     self.funevent(configuration['fittheory'])
                 if configuration['fitbkg']    is None:
-                    if QTVERSION < '4.0.0': self.guiconfig.BkgComBox.setCurrentItem(1)
-                    else: self.guiconfig.BkgComBox.setCurrentIndex(1)
-                    self.bkgevent(self.specfit.bkgdict.keys()[0])
+                    if QTVERSION < '4.0.0':
+                        self.guiconfig.BkgComBox.setCurrentItem(1)
+                    else:
+                        self.guiconfig.BkgComBox.setCurrentIndex(1)
+                    self.bkgevent(list(self.specfit.bkgdict.keys())[0])
                 else:
                     self.bkgevent(configuration['fitbkg'])
             else:
@@ -131,7 +141,7 @@ class SpecfitGUI(qt.QWidget):
                     self.guiconfig.BkgComBox.setCurrentIndex(1)
                     self.guiconfig.FunComBox.setCurrentIndex(1)
                 self.funevent(self.specfit.theorylist[0])
-                self.bkgevent(self.specfit.bkgdict.keys()[0])
+                self.bkgevent(list(self.specfit.bkgdict.keys())[0])
             configuration.update(self.configure())
             if configuration['McaMode']:            
                 self.guiconfig.MCACheckBox.setChecked(1)
@@ -189,18 +199,21 @@ class SpecfitGUI(qt.QWidget):
                     self.guiconfig.FunComBox.setCurrentIndex(i)
                 self.funevent(self.specfit.fitconfig['fittheory'])
             except:
-                print  "Function not in list"
+                print("Function not in list %s" %\
+                      self.specfit.fitconfig['fittheory'])
                 self.funevent(self.specfit.theorylist[0])
             #current background
             try:
-                i=1+self.specfit.bkgdict.keys().index(self.specfit.fitconfig['fitbkg'])
+                #the list conversion is needed in python 3.
+                i=1+list(self.specfit.bkgdict.keys()).index(self.specfit.fitconfig['fitbkg'])
                 if QTVERSION < '4.0.0':
                     self.guiconfig.BkgComBox.setCurrentItem(i)
                 else:
                     self.guiconfig.BkgComBox.setCurrentIndex(i)
             except:
-                print "Background not in list"
-                self.bkgevent(self.specfit.bkgdict.keys()[0])
+                print("Background not in list %s" %\
+                      self.specfit.fitconfig['fitbkg'])
+                self.bkgevent(list(self.specfit.bkgdict.keys())[0])
             #and all the rest
             if configuration['McaMode']:            
                 self.guiconfig.MCACheckBox.setChecked(1)
@@ -246,7 +259,8 @@ class SpecfitGUI(qt.QWidget):
             sheet2={'notetitle':'Search',
                 'fields':(["EntryField",'FwhmPoints', 'Fwhm Points: '],
                           ["EntryField",'Sensitivity','Sensitivity: '],
-                          ["EntryField",'Yscaling',   'Y Factor   : '])}
+                          ["EntryField",'Yscaling',   'Y Factor   : '],
+                          ["CheckField",'ForcePeakPresence',   'Force peak presence '])}
             w=QScriptOption.QScriptOption(self,name='Fit Configuration',
                             sheets=(sheet1,sheet2),
                             default=oldconfiguration)
@@ -279,6 +293,8 @@ class SpecfitGUI(qt.QWidget):
                     self.emit(qt.PYSIGNAL('SpecfitGUISignal'),(ddict,))
                 else:
                     self.emit(qt.SIGNAL('SpecfitGUISignal'), ddict)
+                if DEBUG:
+                    raise
                 return
             self.guiparameters.fillfrommca(mcaresult)
             ddict={}
@@ -307,11 +323,15 @@ class SpecfitGUI(qt.QWidget):
                         msg.exec_()
                     return
             except:
+                if DEBUG:
+                    raise
                 msg = qt.QMessageBox(self)
                 msg.setIcon(qt.QMessageBox.Critical)
                 msg.setText("Error on estimate: %s" % sys.exc_info()[1])
-                if QTVERSION < '4.0.0':msg.exec_loop()
-                else: msg.exec_()
+                if QTVERSION < '4.0.0':
+                    msg.exec_loop()
+                else:
+                    msg.exec_()
                 return
             self.guiparameters.fillfromfit(self.specfit.paramlist,current='Fit')
             self.guiparameters.removeallviews(keep='Fit')
@@ -339,8 +359,12 @@ class SpecfitGUI(qt.QWidget):
                 msg = qt.QMessageBox(self)
                 msg.setIcon(qt.QMessageBox.Critical)
                 msg.setText("Error on mcafit: %s" % sys.exc_info()[1])
-                if QTVERSION < '4.0.0':msg.exec_loop()
-                else: msg.exec_()
+                if QTVERSION < '4.0.0':
+                    msg.exec_loop()
+                else:
+                    msg.exec_()
+                if DEBUG:
+                    raise
                 return
             self.guiparameters.fillfrommca(mcaresult)
             ddict={}
@@ -355,16 +379,23 @@ class SpecfitGUI(qt.QWidget):
             #for param in self.specfit.paramlist:
             #    print param['name'],param['group'],param['estimation']
             self.specfit.paramlist=self.guiparameters.fillfitfromtable()
-            #for param in self.specfit.paramlist:
-            #    print param['name'],param['group'],param['estimation']
+            if DEBUG:
+                for param in self.specfit.paramlist:
+                    print(param['name'],param['group'],param['estimation'])
+                print("TESTING")
+                self.specfit.startfit()
             try:
                 self.specfit.startfit()
             except:
                 msg = qt.QMessageBox(self)
                 msg.setIcon(qt.QMessageBox.Critical)
                 msg.setText("Error on Fit")
-                if QTVERSION < '4.0.0':msg.exec_loop()
-                else: msg.exec_()
+                if QTVERSION < '4.0.0':
+                    msg.exec_loop()
+                else:
+                    msg.exec_()
+                if DEBUG:
+                    raise
                 return
             self.guiparameters.fillfromfit(self.specfit.paramlist,current='Fit')
             self.guiparameters.removeallviews(keep='Fit')
@@ -415,16 +446,8 @@ class SpecfitGUI(qt.QWidget):
             richtext.setWidth(painter,view.width())
             page = 1                
             while(1):
-                if qt.qVersion() < '3.0.0':
-                    richtext.draw(painter,body.left(),body.top(),
-                                qt.QRegion(0.5*margin, margin, metrics.width()- 1 * margin, metrics.height() - 2 * margin),
-                                qt.QColorGroup())
-                    #richtext.draw(painter,body.left(),body.top(),
-                    #            qt.QRegion(view),
-                    #            qt.QColorGroup())
-                else:
-                    richtext.draw(painter,body.left(),body.top(),
-                                view,qt.QColorGroup())
+                richtext.draw(painter,body.left(),body.top(),
+                              view,qt.QColorGroup())
                 view.moveBy(0, body.height())
                 painter.translate(0, -body.height())
                 painter.drawText(view.right()  - painter.fontMetrics().width(qt.QString.number(page)),
@@ -501,7 +524,7 @@ class SpecfitGUI(qt.QWidget):
         if item in self.specfit.theorylist:
             self.specfit.settheory(item)
         else:
-            #if qVersion()>="3.0.0":
+            # TODO why this strange condition
             if 1:
                 fn = qt.QFileDialog.getOpenFileName()
             else:
@@ -557,8 +580,8 @@ class SpecfitGUI(qt.QWidget):
                                        'xmax':None})
         if self.specfit.fitconfig['fittheory'] is not None:
           for pname in self.specfit.theorydict[self.specfit.fitconfig['fittheory']][1]:
-            self.specfit.final_theory.append(pname+`1`)
-            self.specfit.paramlist.append({'name':pname+`1`,
+            self.specfit.final_theory.append(pname+"1")
+            self.specfit.paramlist.append({'name':pname+"1",
                                        'estimation':0,
                                        'group':1,
                                        'code':'FREE',
@@ -577,14 +600,14 @@ class SpecfitGUI(qt.QWidget):
         return
 
     def fitstatus(self,data):
-        if data.has_key('chisq'):
+        if 'chisq' in data:
             if data['chisq'] is None:
                 self.guistatus.ChisqLine.setText(" ")
             else:
                 chisq=data['chisq']
                 self.guistatus.ChisqLine.setText("%6.2f" % chisq)
             
-        if data.has_key('status'):
+        if 'status' in data:
             status=data['status']
             self.guistatus.StatusLine.setText(str(status))
         return
@@ -596,20 +619,20 @@ class SpecfitGUI(qt.QWidget):
         return
         
 if __name__ == "__main__":
-    import numpy.oldnumeric as Numeric
-    import SpecfitFunctions
+    import numpy
+    from PyMca import SpecfitFunctions
     a=SpecfitFunctions.SpecfitFunctions()
-    x = Numeric.arange(2000).astype(Numeric.Float)
-    p1 = Numeric.array([1500,100.,30.0])
-    p2 = Numeric.array([1500,300.,30.0])
-    p3 = Numeric.array([1500,500.,30.0])
-    p4 = Numeric.array([1500,700.,30.0])
-    p5 = Numeric.array([1500,900.,30.0])
-    p6 = Numeric.array([1500,1100.,30.0])
-    p7 = Numeric.array([1500,1300.,30.0])
-    p8 = Numeric.array([1500,1500.,30.0])
-    p9 = Numeric.array([1500,1700.,30.0])
-    p10 = Numeric.array([1500,1900.,30.0])
+    x = numpy.arange(2000).astype(numpy.float)
+    p1 = numpy.array([1500,100.,30.0])
+    p2 = numpy.array([1500,300.,30.0])
+    p3 = numpy.array([1500,500.,30.0])
+    p4 = numpy.array([1500,700.,30.0])
+    p5 = numpy.array([1500,900.,30.0])
+    p6 = numpy.array([1500,1100.,30.0])
+    p7 = numpy.array([1500,1300.,30.0])
+    p8 = numpy.array([1500,1500.,30.0])
+    p9 = numpy.array([1500,1700.,30.0])
+    p10 = numpy.array([1500,1900.,30.0])
     y = a.gauss(p1,x)+1
     y = y + a.gauss(p2,x)
     y = y + a.gauss(p3,x)
@@ -632,6 +655,3 @@ if __name__ == "__main__":
     else:
         w.show()
         a.exec_()
-
-
-    
