@@ -31,14 +31,14 @@ import copy
 from PyMca import PyMcaQt as qt
 from PyMca import PyMcaDirs
 from PyMca import DataObject
-from PyMca import MRCMap
-from PyMca import OmnicMap
-from PyMca import OpusDPTMap
-from PyMca import LuciaMap
-from PyMca import SupaVisioMap
-from PyMca import AifiraMap
-from PyMca import TextImageStack
-from PyMca import TiffStack
+from PyMca.PyMcaIO import MRCMap
+from PyMca.PyMcaIO import OmnicMap
+from PyMca.PyMcaIO import OpusDPTMap
+from PyMca.PyMcaIO import LuciaMap
+from PyMca.PyMcaIO import SupaVisioMap
+from PyMca.PyMcaIO import AifiraMap
+from PyMca.PyMcaIO import TextImageStack
+from PyMca.PyMcaIO import TiffStack
 from PyMca.QEDFStackWidget import QStack, QSpecFileStack
 try:
     from PyMca import QHDF5Stack1D
@@ -140,7 +140,8 @@ class StackSelector(object):
                  filelist[0].upper().endswith("CCD.GZ")or\
                  filelist[0].upper().endswith("RAW.BZ2")or\
                  filelist[0].upper().endswith("EDF.BZ2")or\
-                 filelist[0].upper().endswith("CCD.BZ2"):
+                 filelist[0].upper().endswith("CCD.BZ2")or\
+                 filelist[0].upper().endswith(".CBF"):
                 if imagestack is None:
                     imagestack = True
                 stack = QStack(imagestack=imagestack)
@@ -383,7 +384,7 @@ class StackSelector(object):
         if getfilter is None:
             getfilter = False
         fileTypeList = ["EDF Files (*edf)",
-                        "Image Files (*edf *ccd *raw *edf.gz *ccd.gz *raw.gz)",
+                        "Image Files (*edf *ccd *raw *edf.gz *ccd.gz *raw.gz *cbf)",
                         "Image Files (*tif *tiff *TIF *TIFF)",
                         "TextImage Files (*txt)",
                         "HDF5 Files (*.nxs *.hdf *.h5)",
