@@ -1,30 +1,20 @@
 #/*##########################################################################
-# Copyright (C) 2004-2010 European Synchrotron Radiation Facility
+# Copyright (C) 2004-2013 European Synchrotron Radiation Facility
 #
-# This file is part of the PyMCA X-ray Fluorescence Toolkit developed at
-# the ESRF by the Beamline Instrumentation Software Support (BLISS) group.
+# This file is part of the PyMca X-ray Fluorescence Toolkit developed at
+# the ESRF by the Software group.
 #
-# This toolkit is free software; you can redistribute it and/or modify it 
-# under the terms of the GNU General Public License as published by the Free
-# Software Foundation; either version 2 of the License, or (at your option) 
+# This file is free software; you can redistribute it and/or modify it
+# under the terms of the GNU Lesser General Public License as published by the Free
+# Software Foundation; either version 2 of the License, or (at your option)
 # any later version.
 #
-# PyMCA is distributed in the hope that it will be useful, but WITHOUT ANY
+# This file is distributed in the hope that it will be useful, but WITHOUT ANY
 # WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
-# FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
+# FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
 # details.
 #
-# You should have received a copy of the GNU General Public License along with
-# PyMCA; if not, write to the Free Software Foundation, Inc., 59 Temple Place,
-# Suite 330, Boston, MA 02111-1307, USA.
-#
-# PyMCA follows the dual licensing model of Trolltech's Qt and Riverbank's PyQt
-# and cannot be used as a free plugin for a non-free program. 
-#
-# Please contact the ESRF industrial unit (industry@esrf.fr) if this license 
-# is a problem for you.
 #############################################################################*/
-/*char RcsId[] = "$Header: /segfs/bliss/source/python/specfile/specfile-3.1/src/RCS/specfile_py.c,v 1.9 2005/05/25 13:30:16 sole Exp $"; */
 /************************************************************************
  *
  *   File:          specfile_py.c
@@ -128,6 +118,9 @@ PERFORMANCE OF THIS SOFTWARE.
 #ifndef WIN32
 #include <Python.h>
 #endif
+/* adding next line may raise errors ...
+#define NPY_NO_DEPRECATED_API NPY_1_7_API_VERSION
+*/
 
 #include <numpy/arrayobject.h>
 #include <SpecFile.h>
@@ -688,7 +681,7 @@ scandata_data(PyObject *self,PyObject *args) {
 
     dimensions[0] = data_info[1];
     dimensions[1] = data_info[0];
-    r_array = (PyArrayObject *)PyArray_SimpleNew(2,dimensions,PyArray_DOUBLE);
+    r_array = (PyArrayObject *)PyArray_SimpleNew(2,dimensions,NPY_DOUBLE);
 
    /*
     * Copy
@@ -698,7 +691,7 @@ scandata_data(PyObject *self,PyObject *args) {
     for (i=0;i<dimensions[0];i++) {
        for (j=0;j<dimensions[1];j++) {
           didx = j + i * dimensions[1];
-          ((double *)r_array->data)[didx] = data[j][i];
+          ((double *)PyArray_DATA(r_array))[didx] = data[j][i];
        }
     }
     /* memcpy(array->data,data,PyArray_NBYTES(array)); */
@@ -737,9 +730,9 @@ scandata_dataline(PyObject *self,PyObject *args) {
     if (ret == -1 )
           onError("cannot get data for line");
 
-    r_array  = (PyArrayObject *)PyArray_SimpleNew(1,&ret,PyArray_DOUBLE);
+    r_array  = (PyArrayObject *)PyArray_SimpleNew(1,&ret,NPY_DOUBLE);
 
-    memcpy(r_array->data,data,PyArray_NBYTES(r_array));
+    memcpy(PyArray_DATA(r_array),data,PyArray_NBYTES(r_array));
 
     return (PyObject *)r_array;
 }
@@ -775,10 +768,10 @@ scandata_datacol(PyObject *self,PyObject *args) {
     if (ret == -1 )
       onError("cannot get data for column");
     
-    r_array      = (PyArrayObject *)PyArray_SimpleNew(1,&ret,PyArray_DOUBLE);
+    r_array      = (PyArrayObject *)PyArray_SimpleNew(1,&ret,NPY_DOUBLE);
     
    if (data != (double *) NULL){
-        memcpy(r_array->data,data,PyArray_NBYTES(r_array));
+        memcpy(PyArray_DATA(r_array),data,PyArray_NBYTES(r_array));
         free(data);
     }else{
         /* return an empty array? */
@@ -1159,11 +1152,11 @@ scandata_mca      (PyObject *self,PyObject *args)
     if (ret == -1) 
         onError("cannot get mca for scan");
 
-    r_array = (PyArrayObject *)PyArray_SimpleNew(1,&ret,PyArray_DOUBLE);
+    r_array = (PyArrayObject *)PyArray_SimpleNew(1,&ret,NPY_DOUBLE);
 
 
     if (mcadata != (double *) NULL){
-        memcpy(r_array->data,mcadata,PyArray_NBYTES(r_array));
+        memcpy(PyArray_DATA(r_array),mcadata,PyArray_NBYTES(r_array));
         free(mcadata);
     }else{
         printf("I should give back an empty array\n");
@@ -1266,13 +1259,13 @@ scandata_col(PyObject *self, Py_ssize_t index) {
     if (ret == -1 )
           onError("cannot get data for column");
 
-    r_array = (PyArrayObject *)PyArray_SimpleNew(1,&ret,PyArray_DOUBLE);
+    r_array = (PyArrayObject *)PyArray_SimpleNew(1,&ret,NPY_DOUBLE);
 
     if ( r_array == NULL ) 
           onError("cannot get memory for array data");
 
     if (data != (double *) NULL){
-        memcpy(r_array->data,data,PyArray_NBYTES(r_array));
+        memcpy(PyArray_DATA(r_array),data,PyArray_NBYTES(r_array));
         free(data);
     }else{
         /* return an empty array? */
