@@ -1,5 +1,5 @@
 #/*##########################################################################
-# Copyright (C) 2004 - 2012 European Synchrotron Radiation Facility
+# Copyright (C) 2004 - 2014 European Synchrotron Radiation Facility
 #
 # This file is part of the PyMca X-ray Fluorescence Toolkit developed at
 # the ESRF by the Software group.
@@ -32,7 +32,7 @@ class testEdfFile(unittest.TestCase):
         os.close(tmpFile[0])
         self.fname = tmpFile[1]
         try:
-            from PyMca.EdfFile import EdfFile
+            from PyMca.PyMcaIO.EdfFile import EdfFile
             self.fileClass = EdfFile
         except:
             self.fileClass = None
