@@ -1,4 +1,29 @@
 #!python
+#
+#    Copyright (C) 2004-2013 V. Armando Sole - ESRF
+#
+# Permission is hereby granted, free of charge, to any person
+# obtaining a copy of this software and associated documentation
+# files (the "Software"), to deal in the Software without
+# restriction, including without limitation the rights to use,
+# copy, modify, merge, publish, distribute, sublicense, and/or sell
+# copies of the Software, and to permit persons to whom the
+# Software is furnished to do so, subject to the following
+# conditions:
+#
+# The above copyright notice and this permission notice shall be
+# included in all copies or substantial portions of the Software.
+#
+# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
+# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
+# OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
+# NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
+# HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
+# WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
+# FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
+# OTHER DEALINGS IN THE SOFTWARE.
+#
+__license__ = "MIT"
 """Windows-specific part of the installation"""
 
 import os, sys, shutil
@@ -106,5 +131,5 @@ if len(sys.argv) > 1:
     elif sys.argv[1] in ['-remove', 'remove']:
         remove()
     else:
-        print "Script was called with option %s" % sys.argv[1]
-        print "It has to be called with option -install or -remove"
+        print("Script was called with option %s" % sys.argv[1])
+        print("It has to be called with option -install or -remove")
